/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 06128
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1991
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 06128-0001-statasetup.do)
 |
 **************************************************************************/

set mem 90m  /* Allocating 90 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.\n
**********************************************************/


label data "National Household Survey on Drug Abuse, 1991, Dataset 0001"

#delimit ;
label define CWEOCC2   994 "DONT KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ROCCUP2   995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define BUSINES2  990 "INDUSTRY NOT REPORTED" 995 "BAD DATA"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CWEBUS2   990 "INDUSTRY NOT REPORTED" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SNUFREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED SMOKELESS TOBACCO Logically i"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       98 "BLANK (NO ANSWER)" ;
label define ALCREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ALCOHOL Logically imputed"
                       91 "NEVER USED ALCOHOL" ;
label define SEDREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define TRANREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define STIMREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       83 "NEVER USED AMPHETAMINES W/A NEEDLE Logic"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define ANALREC   1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define MJREC     1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED MARIJUANA Logically imputed"
                       91 "NEVER USED MARIJUANA" ;
label define INHREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically imputed"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define CRAKREC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED CRACK Logically imputed"
                       91 "NEVER USED CRACK" 98 "BLANK (NO ANSWER)" ;
label define COCREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than year"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED COCAINE Logically imputed"
                       91 "NEVER USED COCAINE" ;
label define CONDLREC  1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED COCAINE Logically imputed"
                       83 "NEVER USED COCAINE WITH A NEEDLE Logic.i"
                       91 "NEVER USED COCAINE"
                       93 "NEVER USED COCAINE WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PCPREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED PCP Logically imputed"
                       91 "NEVER USED PCP" 97 "REFUSED" ;
label define HALLREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HALLUCINOGENS Logically imput"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HEROIN Logically imputed"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HEROIN Logically imputed"
                       83 "NEVER USED HEROIN WITH A NEEDLE Logicall"
                       91 "NEVER USED HEROIN"
                       93 "NEVER USED HEROIN WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ANY DRUG FOR NONMDCL RSN Log."
                       83 "NEVER USED A NEEDLE TO TAKE ANY DRUG Log"
                       91 "NEVER USED ANY DRUG FOR NONMEDICAL REASO"
                       93 "NEER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ICEREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ICE Logically assigned"
                       91 "NEVER USED ICE" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STERREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ANABOLIC STEROIDS Logically i"
                       91 "NEVER USED ANABOLIC STEROIDS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCSED    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCTRAN   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCSTM    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCANAL   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCMJ     1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCINH    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCCOC    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCHAL    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCOPT    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define ALCNONE   1 "Response circled" 2 "Response not circled"
                       85 "MULTIPLE RESPONSE"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define CIGTRY    185 "BAD DATA Logically assigned"
                       191 "NEVER USED CIGARETTES" 194 "DONT KNOW"
                       198 "BLANK (NO ANSWER)" ;
label define CIGAGE    181 "NEVER USED CIGARETTES Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED CIGARETTES" 193 "NEVER SMOKED DAILY"
                       194 "DONT KNOW" 198 "BLANK (NO ANSWER)" ;
label define CIGYRS    181 "NEVER USED CIGARETTES Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED CIGARETTES" 194 "DONT KNOW"
                       197 "REFUSED" 198 "BLANK (NO ANSWER)"
                       199 "LEGITIMATE SKIP (CIGAGE = 193)" ;
label define ALCTRY    181 "NEVER USED ALCOHOL Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED ALCOHOL" 194 "DONT KNOW" 197 "REFUSED"
                       198 "BLANK (NO ANSWER)" ;
label define ALCAGE    181 "NEVER USED ALCOHOL Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED ALCOHOL"
                       193 "NEVER USED ALCOHOL MONTHLY OR MORE OFTEN"
                       194 "DONT KNOW" 197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define SEDAGE    181 "NEVER USED SEDATIVES Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED SEDATIVES" 194 "DONT KNOW"
                       198 "BLANK (NO ANSWER)" ;
label define TRANAGE   181 "NEVER USED TRANQUILIZERS Logically assig"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED TRANQUILIZERS" 194 "DONT KNOW"
                       198 "BLANK (NO ANSWER)" ;
label define STIMAGE   181 "NEVER USED STIMULANTS Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED STIMULANTS" 198 "BLANK (NO ANSWER)" ;
label define ANALAGE   181 "NEVER USED ANALGESICS Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED ANALGESICS" 194 "DONT KNOW"
                       198 "BLANK (NO ANSWER)" ;
label define MJOPP     181 "NEVER HAD CHANCE TO TRY MARIJUANA Log. a"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD CHANCE TO TRY MARIJUANA"
                       194 "DONT KNOW" 198 "BLANK (NO ANSWER)" ;
label define MJAGE     181 "NEVER USED MARIJUANA Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED MARIJUANA" 194 "DONT KNOW"
                       197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define INHAGE    181 "NEVER USED INHALANTS Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED INHALANTS" 194 "DONT KNOW"
                       198 "BLANK (NO ANSWER)" ;
label define COCOPP    181 "NEVER HAD A CHANCE TO TRY COCAINE Log. a"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD A CHANCE TO TRY COCAINE"
                       194 "DONT KNOW" 198 "BLANK (NO ANSWER)" ;
label define COCAGE    181 "NEVER USED COCAINE Logically assigned"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED COCAINE" 197 "REFUSED"
                       198 "BLANK (NO ANSWER)" ;
label define HALLOPP   181 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS"
                       194 "DONT KNOW" 197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define HALLAGE   181 "NEVER USED HALLUCINOGENS Logically assig"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED HALLUCINOGENS" 194 "DONT KNOW"
                       197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define HEROPP    181 "NEVER HAD A CHANCE TO TRY HEROIN Log. as"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD A CHANCE TO TRY HEROIN" 194 "DONT KNOW"
                       197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define HERAGE    181 "NEVER HAD A CHANCE TO TRY HEROIN Log. as"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER HAD A CHANCE TO TRY HEROIN" 197 "REFUSED"
                       198 "BLANK (NO ANSWER)" ;
label define STEROPP   181 "NEVER USED ANABOLIC STEROIDS Logically a"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED ANABOLIC STEROIDS" 194 "DONT KNOW"
                       197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define STERAGE   181 "NEVER USED ANABOLIC STEROIDS Logically a"
                       185 "BAD DATA Logically assigned"
                       191 "NEVER USED ANABOLIC STEROIDS" 197 "REFUSED"
                       198 "BLANK (NO ANSWER)" ;
label define OTHTOB    1 "Daily" 2 "Almost daily (3-6 days a week)"
                       3 "1 or 2 days a week"
                       4 "Several times a month (25-51 days a year"
                       5 "1 or 2 times a month (12-24 days a year)"
                       6 "Every other month or so (6-11 days a yea"
                       7 "3-5 days this past year"
                       8 "1 or 2 days this past year"
                       81 "NEVER USED SMOKELESS TOBACCO Logically a"
                       83 "DID NOT USE SMOKELESS TOBACCO PST YR Log"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO IN LIFETIME"
                       93 "DID NOT USE SMOKELESS TOBACCO IN THE PAS"
                       98 "BLANK (NO ANSWER)" ;
label define ALCPAT    1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25-51 days)"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS Log. ass"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTH"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define SEDYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (25-51 days a year"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       83 "DID NOT USE SEDATIVE PAST 12 MOS Log. as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE ANY SEDATIVE IN THE PAST 12"
                       98 "BLANK (NO ANSWER)" ;
label define TRNYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (25-51 days a year"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       83 "DID NOT USE TRANQUILIZER PAST 12 MOS Log"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE ANY TRANQUILIZER IN THE PAST"
                       98 "BLANK (NO ANSWER)" ;
label define STMYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "DID NOT USE STIMULANT PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN THE PAST 12 MON"
                       98 "BLANK (NO ANSWER)" ;
label define ANLYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED ANALGESICS Logically assigned"
                       83 "DID NOT USE ANALGESIC PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESIC IN THE PAST 12 MON"
                       98 "BLANK (NO ANSWER)" ;
label define MJYRFREQ  1 "Several times a day" 2 "Daily"
                       3 "Almost daily (3 to 6 days a week)"
                       4 "1 or 2 days a week"
                       5 "Several times a month (about 25 to 51 da"
                       6 "1 to 2 times a month (12 to 24 days a ye"
                       7 "Every other month or so (6 to 11 days a"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 or 2 days in the past 12 months"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define INHYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS Log. as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN THE PAST 12 MONT"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define COCYRFRQ  1 "Daily" 2 "Almost daily (3 to 6 days a week)"
                       3 "1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 12 MONTHS Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define HALYRFRQ  1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a y"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 to 2 days in the past 12 months"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       83 "DID NOT USE HALLUCINOGEN PAST 12 MOS Log"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGEN IN THE PAST 12"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIG5PK    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PACKS     1 "One to five cigarettes a day"
                       2 "About 1/2 pack a day(6-15 cigarettes)"
                       3 "About a pack a day(16-25 cigarettes)"
                       4 "About 1 1/2 packs a day(26-35 cigarettes"
                       5 "About 2 packs or more a day (over 35 cig"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (CIGAGE = 193)" ;
label define AVCIG     1 "Less than one cigarette a day"
                       2 "one to five cigarettes a day"
                       3 "About 1/2 pack a day (6-15 cigarettes)"
                       4 "About a pack a day (16-25 cigarettes)"
                       5 "About 1 1/2 packs a day (26-35 cigarette"
                       6 "About 2 packs or more a day (over 35 cig"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CIGTIME   9981 "NEVER USED CIGARETTES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED CIGARETTES" 9994 "DONT KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define ALCDAYS   81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NODR30A   2 "USUAL # DRINKS PER DAY PAST 30 DAYS"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define DR5DAY    81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MODR30A   2 "MOST # DRINKS ON ONE DAY IN PAST 30 DAYS"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MODR30DY  2 "# DAYS DRANK AMOUNT IN A-7 PAST 30 DAYS"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRUNKYR   1 "Daily" 2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25-51 days"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       9 "Never got very high or drunk in past 12"
                       81 "NEVER USE ALCOHOL Logically assigned"
                       83 "DID NOT USED ALCOHOL PAST 12 MOS. Log"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTH"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCBEER   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 97 "REFUSED" ;
label define ALCWINE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED" ;
label define ALCLIQR   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED" ;
label define ALCVARY   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED" ;
label define NOBOOZYR  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" ;
label define ALCAGGR   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCARGUM  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCABSNT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCHIGH   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCJOB    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCMATCD  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCRELCD  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCFRDCD  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCTOSS   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCHOLIC  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCDRUNK  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCINTOX  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCREM    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCQUICK  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCMORN   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCSHOOK  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCALONE  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCBRKPM  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BUTISOL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define BUTICAPS  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMYTAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define MEBARAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PLACIDYL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DORIDEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NOLUDAR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NEMBUTAL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECONAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define TUINAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DALMANE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define RESTORIL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define HALCION   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMOBARB   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PHENOBAR  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define METHAQ    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define CHHYD     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PENTOB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECOB     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Sedative use LOGICALLY ASSIGNED"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   116 "Methaqualone (including Sopor, Quaalude)"
                       120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       122 "Sleep Aid <OTC>" 123 "Unisom <OTC>" 129 "Reds"
                       131 "Haldol" 133 "Ryoxine (sic)" 135 "Mini Thins"
                       138 "Mandrax (sic)" 139 "Black widows"
                       143 "Sedoxen (sic)" 144 "Reynolds (sic)" 201 "Valium"
                       206 "Tranxene" 209 "Xanax" 227 "Thorazine"
                       234 "Flexeril, Cyclobenzaprine"
                       240 "Lithium Carbonate" 244 "sic"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       326 "White cross" 327 "Black Beauty, Black beauties"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 352 "Lemons"
                       362 "Benadryl" 364 "Sudafed, Sinutab" 401 "Darvon"
                       408 "Dilaudid" 409 "Tylenol with Codeine, Tylenol 3"
                       411 "Talwin" 415 "Codeine" 417 "Morphine"
                       420 "OTHER Analgesic, NOT SPECIFIED" 423 "Percocet"
                       425 "Advil"
                       426 "Fiorinal, Butalbital, Phrenilin Forte"
                       427 "Darvocet" 430 "Aspirin, Ecotrin, Empirin <OTC>"
                       435 "Tylenol <OTC>"
                       530 "Asthma inhaler, Bronchial dilators"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 820 "Penicillin"
                       828 "Tetracycline"
                       981 "NEVER USED SEDATIVES Logically assigned"
                       991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWB   120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       136 "Dimetapp" 202 "Librium"
                       339 "Amphetamines (speed generically)"
                       364 "Sudafed, Sinutab" 407 "Demerol"
                       414 "Propoxyphene" 417 "Morphine" 422 "Motrin"
                       440 "Soma" 444 "Empirin 3"
                       605 "PCP (angel dust, phencyclidine)"
                       991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWC   324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       426 "Fiorinal, Butalbital, Phrenilin Forte"
                       991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWD   120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWE   991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NOSEDAT   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define VALIUM    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIBRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIMBTROL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MENRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SERAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANXENE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATIVAN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define CENTRAX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define XANAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define PAXIPAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define BUSPAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MILTOWN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define EQUANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DEPROL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define VISTAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATARAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DURRAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DIAZEPAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SKLY      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MEPROB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNOSP    1 "Response circled" 2 "Response not circled"
                       3 "Tranquilizer use LOGICALLY ASSIGNED"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNEWA    116 "Methaqualone (including Sopor, Quaalude)"
                       128 "Nervine <OTC>" 138 "Mandrax (sic)" 211 "Buspar"
                       218 "Diazepam" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       229 "Librax" 232 "Mellaril"
                       234 "Flexeril, Cyclobenzaprine" 239 "Elavil"
                       240 "Lithium Carbonate" 241 "Prozac" 245 "Tryptophan"
                       246 "Clonopin" 248 "Sooper Cool (sic)" 249 "Asendin"
                       328 "Pink hearts" 415 "Codeine" 440 "Soma"
                       443 "Dolobid" 458 "Mepergan Fortis" 459 "Ketamine"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       802 "THC, Cannabinol" 991 "NEVER USED TRANQUILIZERS"
                       998 "BLANK (NO ANSWER)" ;
label define TRNEWB    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWC    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWD    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWE    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRDKNAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define NOTRANQ   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       98 "BLANK (NO ANSWER)" ;
label define TRANTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       85 "DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DEXED     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DEXAMYL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ESKAT     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BENZ      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BIPHET    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DESOXYN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TENUATE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TEPANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DIDREX    1 "Response circled" 2 "not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PLEGINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PRELUDIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define IONAMIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FASTIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PONDIMIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define VORANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SANOREX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MAZANOR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RITALIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CYLERT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DETAMP    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHI     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHAMP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OBLA      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STIMNOSP  1 "Response circled" 2 "Response not circled"
                       3 "Stimulant use LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  124 "Yellow jackets" 135 "Mini Thins" 209 "Xanax"
                       301 "Dexedrine" 303 "Eskatrol"
                       307 "Tenuate, Diethylpropion"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       325 "USED STIMULANT, DONT KNOW NAME" 326 "White cross"
                       327 "Black Beauty, Black beauties" 328 "Pink hearts"
                       329 "Speckled eggs, Robins eggs" 331 "Whites"
                       332 "Ephedrine" 333 "357 Magnum, Magnum 44"
                       334 "Cross tops, Crossroads" 335 "Dexatrim"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)"
                       340 "Tiamina 250 (sic)" 344 "Bennies"
                       345 "Black Molly" 347 "Phenylpropanolamine <OTC>"
                       353 "No-Doz <OTC>" 354 "Vivarin <OTC>"
                       355 "Crystal meth" 357 "Heart-shaped black pills"
                       360 "Rainbow speed" 365 "Desecon (sic)"
                       366 "Duromine (sic)" 367 "Slender Rite (sic)"
                       370 "Mess Tab (sic)" 373 "Captagon (sic)"
                       430 "Aspirin, Ecotrin, Empirin <OTC>"
                       457 "Ts and Blues" 601 "LSD (acid,white lightning)"
                       603 "Mescaline" 605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC" 803 "Marijuana"
                       805 "Cocaine, Coke" 814 "Caffeine" 815 "Coffee"
                       981 "NEVER USED STIMULANTS Logically assigned"
                       991 "NEVER USED STIMULANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNEWB  308 "Tepanil, Diethylpropion"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       326 "White cross" 327 "Black Beauty, Black beauties"
                       328 "Pink hearts" 329 "Speckled eggs, Robins eggs"
                       331 "Whites" 333 "357 Magnum, Magnum 44"
                       334 "Cross tops, Crossroads"
                       357 "Heart-shaped black pills" 805 "Cocaine, Coke"
                       814 "Caffeine" 991 "NEVER USED STIMULANTS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWC  326 "White cross" 330 "Blue birds, Blue jays"
                       334 "Cross tops, Crossroads"
                       991 "NEVER USED STIMULANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNEWD  991 "NEVER USED STIMULANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNEWE  991 "NEVER USED STIMULANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define STMDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NOSTIMS   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       98 "BLANK (NO ANSWER)" ;
label define STIMTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STNEEDLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DARVON    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DOLENE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SK65A     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define WYGESIC   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LEVODRO   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PERCODAN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DEMEROL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DILAUD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TYLCOD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PHENCOD   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TALWIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TALWINNX  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TALACEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PROPOXY   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CODEINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANILERID  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MORPHINE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHDON   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STADOL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANLNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Analgesic use LOGICALLY ASSIGNED"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  234 "Flexeril, Cyclobenzaprine"
                       313 "Fastin, Phentermine" 362 "Benadryl"
                       364 "Sudafed, Sinutab" 406 "Percodan, Oxycodone"
                       407 "Demerol" 409 "Tylenol with Codeine, Tylenol 3"
                       415 "Codeine" 420 "OTHER Analgesic, NOT SPECIFIED"
                       422 "Motrin" 423 "Percocet" 425 "Advil"
                       426 "Fiorinal, Butalbital, Phrenilin Forte"
                       427 "Darvocet" 430 "Aspirin, Ecotrin, Empirin <OTC>"
                       431 "Tylox" 434 "Vicodin, Hydrocodone, Co-Gesic"
                       435 "Tylenol <OTC>" 438 "Anaprox, Naprosyn"
                       439 "222, Canadian 222" 440 "Soma" 441 "Luitab (sic)"
                       442 "Ibuprofen" 445 "Norgesic Forte"
                       455 "Fiorinal with Codeine" 458 "Mepergan Fortis"
                       461 "Daopar (sic)" 463 "Lisalgil (sic)"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED"
                       981 "NEVER USED ANALGESICS Logically assigned"
                       991 "NEVER USED ANALGESICS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWB  222 "USED TRANQUILIZER, DONT KNOW NAME"
                       353 "No-Doz <OTC>" 364 "Sudafed, Sinutab" 422 "Motrin"
                       426 "Fiorinal, Butalbital, Phrenilin Forte"
                       455 "Fiorinal with Codeine" 458 "Mepergan Fortis"
                       460 "Magnopyrol (sic)" 702 "Heroin"
                       991 "NEVER USED ANALGESICS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWC  991 "NEVER USED ANALGESICS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWD  991 "NEVER USED ANALGESICS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWE  991 "NEVER USED ANALGESICS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define ANLDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANALNONE  1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       98 "BLANK (NO ANSWER)" ;
label define ANALTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANALGESICS" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define MJTOT     1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MJDAY30A  81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MJAV30A   81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define MJAV30B   81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define MJAMT30A  1 "1 to 10 joints in the past 30 days"
                       2 "11 to 20 joints in the past 30 days"
                       3 "About 1 ounce in the past 30 days"
                       4 "About 2 ounces in the past 30 days"
                       5 "3 to 4 ounces in the past 30 days"
                       6 "5 to 6 ounces in the past 30 days"
                       77 "More than 6 ounces in the past 30 days"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Log."
                       85 "BAD DATA Logically-assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define MJJOINT   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS Log. a"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJPIPE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS Log. a"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJBAKE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS Log. a"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJCHEW    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS Log. a"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJWAY     1 "Response circled, method not specified"
                       2 "Response not circled"
                       3 "Response circled, method not specified L"
                       6 "Can with holes" 7 "One hitter" 8 "Boiled with tea"
                       9 "Smoky small room (burn in small room lik"
                       11 "Shot gun" 12 "Chewing/eating"
                       13 "Through an apple made like a pipe" 16 "Laced"
                       17 "Blunts" 18 "Gravities" 19 "With cocaine"
                       20 "Bleach bottle" 21 "Contact" 22 "1 paper"
                       23 "As medicine"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS Logic."
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define GAS       1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define LGAS      1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define SPPAINT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define AEROS     1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define GLUE      1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define SOLVENT   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define AMYLNIT   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define ETHER     1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define NITOXID   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define CLEFLU    1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED INRALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define GAS30A    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Log. a"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define LGAS30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAN30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS Log. as"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define AEROS30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Log. a"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define GLUE30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USED INHALANT PAST 30 DAYS Log."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define SOLVN30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS Log. as"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define AMLNT30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Log. a"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define ETHER30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USED INHALANT PAST 30 DAYS Log."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define NOX30A    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS Log. as"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define CLFL30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Log. a"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define IN30NOSP  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANTS PAST 30 DAYS Log."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define INH30NO   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHDY30A  81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define INHEFF    1 "Enough to feel you were going to pass ou"
                       2 "Enough so that you staggered or dropped"
                       3 "Enough to get high" 4 "Enough to feel it a lot"
                       5 "Enough to feel it a little"
                       6 "Just enough to be able to say I did it,"
                       7 "Something else, NOT SPECIFIED"
                       8 "Didnt feel it, didnt use much"
                       9 "Sniffed out of curiosity once"
                       11 "Enough for a head rush"
                       12 "Didnt feel it, just like the smell"
                       15 "Just enough to say, I tried it, I felt i"
                       16 "Enough to get sick" 17 "Till I couldnt move"
                       18 "Enough smoke" 19 "Scared so I stopped"
                       20 "Smell of gas at the pump, not just to ge"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHPO     1 "Yes" 2 "No"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 98 "BLANK (NO ANSWER)" ;
label define INHNEWA   116 "Methaqualone (including Sopor, Quaalude)"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 432 "Rufen"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine lqd, glue/toluene; SuperGlue;"
                       506 "Amyl nitrite,poppers, lock rm odori"
                       507 "Halothane, ether, or other anesthet"
                       508 "Nitrous oxide,whippets, dentist gas"
                       509 "Correction flds, degreasers, cleaning fl"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens" 512 "Incense"
                       514 "Carbona (sic)" 515 "Vicks" 516 "Freon"
                       518 "Acetone, Nail polish remover" 519 "Helium"
                       522 "TV Tuner" 523 "Matches" 524 "White-Out"
                       526 "Nail polish" 527 "Phenyl nitrate"
                       528 "Whipped-cream can" 529 "Moth balls"
                       530 "Asthma inhaler, Bronchial dilators" 531 "Candy"
                       532 "PRW (sic)" 534 "Deodorant"
                       535 "Rexo (sic] copies" 536 "Fire Halt"
                       537 "Boat horn" 539 "ScotchGard" 540 "PAM"
                       541 "Binaca" 542 "Spirits of ammonia"
                       543 "Liquid oxygen" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       811 "Muscle relaxers"
                       813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 995 "BAD DATA"
                       998 "BLANK (No ANSWER)" ;
label define INHNEWB   504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       509 "Correction flds, degreasers, cleaning fl"
                       518 "Acetone, Nail polish remover" 524 "White-Out"
                       533 "Window sealant" 538 "Condensed horn"
                       805 "Cocaine, Coke"
                       981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INHNEWC   981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INHNEWD   981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INHNEWE   981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 998 "BLANK (NO ANSWER)" ;
label define INNEW30A  503 "Other aerosol sprays"
                       504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       506 "Amyl nitrite,poppers, lock rm odori"
                       509 "Correction flds, degreasers, cleaning fl"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, Felt-tip pens" 514 "Carbona (sic)"
                       516 "Freon" 519 "Helium" 524 "White-Out"
                       526 "Nail polish" 528 "whipped-cream can"
                       539 "ScotchGard" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS" 993 "NOT APPLICABLE"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30B  504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       526 "Nail polish"
                       981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS" 993 "NOT APPLICABLE"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30C  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST 30 DAYS"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30D  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST 30 DAYS"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30E  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST 30 DAYS"
                       998 "BLANK (NO ANSWER)" ;
label define COCTOT    1 "1 or 2 times" 2 "3 to s times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED COCAINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define COCUS30A  81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 30 DAYS Logic.a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define CRKAM30A  981 "NEVER USED Logically assigned"
                       983 "DID NOT USE CRACK IN PAST 30 DAYS Log.as"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK IN PAST 30 DAYS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define CRAKBUCK  9981 "NEVER USED COCAINE Logically assigned"
                       9983 "DID NOT USE CRACK PAST 30 DAYS Log. assi"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CRACK"
                       9993 "DID NOT USE CRACK IN PAST 30 DAYS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define COCAM30A  1 "Less than 1/4 gram (about 4 big lines) p"
                       2 "About 1/4 gram in the past 30 days"
                       3 "About 1/2 gram in the past 30 days"
                       4 "About 1 gram in the past 30 days"
                       5 "About 2 grams in the past 30 days"
                       6 "About 3 grams in the past 30 days" 7 "4 grams"
                       23 "20 grams"
                       77 "More than 3 grams in the past 30 days"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 30 DAYS Log"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define COCBUCK   9981 "NEVER USED COCAINE Logically assigned"
                       9983 "DID NOT USE COCAINE PAST 30 DAYS Log.ass"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED COCAINE"
                       9993 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       9994 "DONT KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define COCSNIFF  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logicall"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       97 "REFUSED" ;
label define COCSWAL   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logicall"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       97 "REFUSED" ;
label define COCIV     1 "Response circled" 2 "Response not circled"
                       3 "Cocaine use LOGICALLY ASSIGNED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 12 MOS Log.a"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       97 "REFUSED" ;
label define FREEBASE  1 "Response circled" 2 "Response not circled"
                       3 "Cocaine use LOGICALLY ASSIGNED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logicall"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       97 "REFUSED" ;
label define COCWAY    1 "Response circled" 2 "Response not circled"
                       3 "Cocaine use LOGICALLY ASSIGNED"
                       6 "Lasing joints and bongs" 7 "On my gums"
                       8 "Freeze, put on tongue" 9 "Smoked in a cigarette"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MONTHS Logic"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define LSD       1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PEYOTE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MESC      1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "LANK (NO ANSWER)" ;
label define PSILCY    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PCP       1 "Response circled" 2 "Response not circled"
                       3 "PCP use LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ECSTASY   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Hallucinogen use LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALNEWA   322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       357 "Heart-shaped black pills" 366 "Duromine (sic)"
                       434 "Vicodin, Hydrocodone, Co-Gesic"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       609 "Jimson (sic) weed" 612 "Happy stick, Shermstick"
                       614 "MDMA" 616 "DMT" 617 "Moming glory seeds"
                       618 "Acid paper" 622 "Microdot(s), purple microdot"
                       624 "Orange sunshine" 625 "Window pane"
                       627 "Hawaiian Woodrow seeds"
                       628 "Hawaiian Rosebud seed tea" 630 "Black Owsley"
                       632 "Folifundia (sic)" 633 "Mr Natural"
                       635 "Ginseng seeds" 703 "Opium" 802 "THC, Cannabinol"
                       981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWB   504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       629 "Rocket Fuel" 802 "THC, Cannabinol"
                       803 "Marijuana"
                       981 "NEVER USED HALLUCINOGENS Logically assig"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWC   981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWD   981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALNEWE   981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALLTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HAL30USE  81 "NEVER USED HALLUCINOGENS Logically assig"
                       83 "DID NOT USE HALLUCINOGENS PST 30 DAYS Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 30"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HER30USE  81 "NEVER USED HEROIN Logically assigned"
                       83 "DID NOT USE HEROIN PAST 30 DAYS Logic.as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 30 DAYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERNEEDL  1 "Yes, have used heroin with a needle"
                       2 "No, have used heroin, but not with a ne"
                       3 "Yes, have used heroin with a needle LOG"
                       4 "No, have used heroin, without needle LOG"
                       81 "NEVER USED HEROIN Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CDCIG     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log.as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDALC     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDSED     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log.as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDTRAN    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDSTM     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDANAL    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDMJ      1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDINH     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDCOC     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDHALL    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDHER     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDOTHOP   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDNONE    1 "Response circled" 2 "Response not circled"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDNONE   1 "Response circled" 2 "Response not circled"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFNONE   1 "Response circled" 2 "Response not circled"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYCIG   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYALC   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYSED   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYTRAN  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYSTM   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYANAL  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYMJ    1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYINH   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYCOC   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYHALL  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYHER   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYOTH   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYNONE  1 "Response circled" 2 "Response not circled"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS.Log as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPNONE   1 "Response circled" 2 "Response not circled"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSCIG     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSALC     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSSED     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSTRAN    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSSTM     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSANAL    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSMJ      1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSINH     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSCOC     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSHALL    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSHER     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSOTHOP   1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSNONE    1 "Response circled" 2 "Response not circled"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS Log. a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLLIF  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED A NEEDLE TO TAKE A DRUG Log."
                       91 "NEVER USED A NEEDLE TO TAKE A DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSED  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLTRA  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY LISTED DRUGS Logically as"
                       83 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLSTM  1 "Response circled" 2 "Response not circled"
                       3 "Response circled Logically imputed"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLANL  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLMJ   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLINH  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLCOC  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLHAL  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLHER  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLOPT  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLNON  2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LIST ABOVE Log. ass"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Log. as"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLSHR  1 "Yes" 2 "No"
                       81 "NEVER SHARED A NEEDLE Logically assigned"
                       91 "NEVER SHARED A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRUGTEST  1 "Yes" 2 "No"
                       3 "Did not have a job during past 12 months"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TESTPOS   1 "Yes" 2 "No"
                       3 "Did not receive test in past 12 months"
                       4 "Did not have a job during past 12 months"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ICELIFE   1 "Yes" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED ICE Logically assigned"
                       91 "NEVER USED ICE" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STERTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED ANABOLIC STEROIDS Logically a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANABOLIC STEROIDS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BOOKED    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NOBOOKYR  185 "BAD DATA Logically assigned" 194 "DONT KNOW"
                       197 "REFUSED" 198 "BLANK (NO ANSWER)" ;
label define BKLARCNY  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKBURGL   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKAGASLT  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKSMASLT  1 "Response circled" 2 "Response not circled"
                       85 "EM DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKMVTHFT  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKROB     1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKRAPE    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKMURDER  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKARSON   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKDRVINF  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKDRUNK   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKDRUG    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKPROS    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKVANDAL  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define BKOTHOFF  1 "Larceny or theft" 3 "Aggravated assault"
                       4 "Other assault, such as simple assault or"
                       5 "Motor vehicle theft"
                       10 "Driving under the influence"
                       11 "Drunkenness or other liquor law violatio"
                       12 "Possession or sale of drugs"
                       14 "Oth proprty offns:- fraud, poss stln goo"
                       15 "Other offenses, NOT SPECIFIED"
                       16 "Weapons offenses"
                       17 "Other offenses against persons"
                       18 "Violation of court order, parole, probat"
                       19 "Public order offenses"
                       20 "Juvenile status offenses" 22 "Traffic violations"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NOTBKED   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define PROBATON  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PAROLE    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STRSTEAL  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHSTEAL  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DAMAGE    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CARSTEAL  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FORCEMON  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BREAKIN   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PHYFIGHT  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HURTBAD   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "EFUSED"
                       98 "LANK (NO ANSWER)" ;
label define GUNMONEY  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRUNKDRV  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SOLDDRUG  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHDOING  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SPNEWA    0 "None (code used only for question SP-9)" 129 "Reds"
                       140 "Seldane"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       328 "Pink Hearts" 332 "Ephedrine"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 360 "Rainbow speed"
                       368 "Peanut Butter Crank" 415 "Codeine"
                       430 "Aspirin, Ecotrin, Empirin <OTC>"
                       454 "Novocain, Procaine" 455 "Fiorinal with Codeine"
                       459 "Ketamine" 501 "Gasoline or lighter fluids"
                       506 "Amyl nitrite,poppers, lock rm odoriz"
                       514 "Carbona (sic)" 601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC"
                       622 "Microdot(s), purple microdot" 626 "Jet Fuel"
                       703 "Opium" 803 "Marijuana" 804 "Hashish"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       823 "Blast (KJ) [sic)" 824 "Steroids"
                       829 "Robitussin DM" 831 "Honey Oil" 832 "Primo"
                       985 "BAD DATA Logically assigned" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWB    0 "None (code used only for question SP-9)"
                       322 "Methamphetamine (speed or ice or cr"
                       326 "White cross"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC" 703 "Opium" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWC    0 "None (code used only for question SP-9)"
                       348 "Crystal" 601 "LSD (acid,white lightning)"
                       805 "Cocaine, Coke" 807 "Alcohol" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define SPNEWD    0 "None (code used only for question SP-9)"
                       605 "PCP (angel dust, phencyclidine)" 807 "Alcohol"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWE    0 "None (code used only for question SP-9)"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define AS13NONE  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" ;
label define DRDEPRSS  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPDRG1A  111 "Dalmane" 113 "Halcion"
                       120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       122 "Sleep Aid <OTC>" 201 "Valium" 207 "Ativan"
                       208 "Centrax" 209 "Xanax" 211 "Buspar"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 406 "Percodan, Oxycodone"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       423 "Percocet" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       830 "Mad Bull"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG2A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       209 "Xanax" 322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 407 "Demerol" 415 "Codeine"
                       418 "Methadone" 601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       606 "Ecstasy (MDMA), X-TC" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG3A  322 "Methamphetamine (,speed or ice or c"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid,white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG4A  355 "Crystal meth" 601 "LSD (acid,white lightning)"
                       803 "Marijuana" 807 "Alcohol" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG5A  994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRARGUM   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ARGDRG1A  118 "Pentobarbital, Pentothal, Sodium Pentoth"
                       201 "Valium" 322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       327 "Black Beauty, Black beauties"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       406 "Percodan, Oxycodone"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       423 "Percocet" 502 "Spray paints"
                       506 "Amyl nitrite,poppers, lock rm odoriz"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       830 "Mad Bull"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG2A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       415 "Codeine"
                       504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       609 "Jimson (sic) weed" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       900 "Non-Drug reason given for Drug Problem"
                       985 "BAD DATA Logically assigned" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG3A  322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid,white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG4A  322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       355 "Crystal meth" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 994 "DONT KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ARGDRG5A  702 "Heroin" 814 "Caffeine" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRALONE   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALNDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 207 "Ativan" 211 "Buspar"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 406 "Percodan, Oxycodone" 415 "Codeine"
                       423 "Percocet" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       830 "Mad Bull"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG2A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG3A  322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       818 "Nicotine" 994 "DONT KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ALNDRG4A  322 "Methamphetamine (speed or ice or cr"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG5A  702 "Heroin" 814 "Caffeine" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRANX     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANXDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 202 "Librium" 207 "Ativan" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine" 313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       326 "White cross" 328 "Pink hearts" 332 "Ephedrine"
                       335 "Dexatrim" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       357 "Heart-shaped black pills" 358 "20/20"
                       360 "Rainbow speed" 364 "Sudafed, Sinutab"
                       406 "Percodan, Oxycodone" 407 "Demerol"
                       409 "Tylenol with Codeine, Tylenol 3"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       435 "Tylenol <OTC>" 501 "Gasoline or lighter fluids"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       609 "Jimson [sic) weed" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 829 "Robitussin DM"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG2A  209 "Xanax" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       326 "White cross" 333 "357 Magnum, Magnum 44"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       415 "Codeine"
                       506 "Amyl nitrite,poppers, lock rm odoriz"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG3A  322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       606 "Ecstasy (MDMA), X-TC"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG4A  322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning)" 603 "Mescaline"
                       604 "Psilocybin (mushrooms)" 803 "Marijuana"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG5A  702 "Heroin" 703 "Opium" 814 "Caffeine"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRHEALTH  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLTDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       123 "Unisom <OTC>" 201 "Valium"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       333 "357 Magnum, Magnum 44"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       409 "Tylenol with Codeine, Tylenol 3"
                       504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG2A  339 "Amphetamines (speed generically)"
                       601 "LSD (acid,white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG4A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid,white lightning)" 803 "Marijuana"
                       807 "Alcohol" 994 "DONT KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define HLTDRG5A  814 "Caffeine" 994 "DONT KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define DRNTHINK  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NTKDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       142 "Belladona" 203 "Limbitrol" 209 "Xanax"
                       228 "Amitriptyline" 241 "Prozac"
                       313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       360 "Rainbow speed" 401 "Darvon"
                       406 "Percodan, Oxycodone"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       422 "Motrin" 423 "Percocet" 462 "Norflex"
                       502 "Spray paints"
                       504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       508 "Nitrous oxide,whippets, dentist gas"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC" 609 "Jimson [sic) weed"
                       702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       830 "Mad Bull"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG2A  201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       247 "Sinequan"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       360 "Rainbow speed" 407 "Demerol" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG3A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG4A  601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       802 "THC, Cannabinol" 803 "Marijuana" 807 "Alcohol"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG5A  503 "Other aerosol sprays"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRUPSET   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define UPSDRG1A  118 "Pentobarbital, Pentothal, Sodium Pentoth"
                       203 "Limbitrol" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine"
                       322 "methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 360 "Rainbow speed"
                       406 "Percodan, Oxycodone" 415 "Codeine"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       809 "Pills" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 830 "Mad Bull"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG2A  209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       502 "Spray paints" 601 "LSD (acid,white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG3A  322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth"
                       506 "Amyl nitrite,poppers, lock rm odoriz"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG4A  503 "Other aerosol sprays" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG5A  994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRLSWORK  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LSWDRG1A  111 "Dalmane" 142 "Belladona" 211 "Buspar"
                       322 "Methamphetamine (speed or ice or cr"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 355 "Crystal meth" 360 "Rainbow speed"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       420 "OTHER Analgesic, NOT SPECIFIED" 422 "Motrin"
                       423 "Percocet" 435 "Tylenol <OTC>"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       609 "Jimson [sic) weed" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG2A  322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       360 "Rainbow speed" 524 "White-Out"
                       601 "LSD (acid,white lightning)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG3A  322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 503 "Other aerosol sprays"
                       601 "LSD (acid, white lightning)"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 807 "Alcohol"
                       818 "Nicotine" 994 "DONT KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define LSWDRG4A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       803 "Marijuana" 807 "Alcohol" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG5A  601 "LSD (acid, white lightning)" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRSUSPIC  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SSPDRG1A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       207 "Ativan" 211 "Buspar"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 360 "Rainbow speed" 371 "Cogentin"
                       415 "Codeine" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       609 "Jimson [sic) weed" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 830 "Mad Bull"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG2A  131 "Haldol" 247 "Sinequan"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 609 "sic"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (No ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG3A  339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 601 "LSD (acid,white lightning)"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       818 "Nicotine" 994 "DONT KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SSPDRG4A  807 "Alcohol" 994 "DONT KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SSPDRG5A  994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRCOPE    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CPEDRG1A  201 "Valium" 207 "Ativan" 211 "Buspar"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 355 "Crystal meth" 360 "Rainbow speed"
                       406 "Percodan, oxycodone"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       420 "OTHER Analgesic, NOT SPECIFIED" 423 "Percocet"
                       502 "Spray paints" 601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG2A  120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       502 "Spray paints"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED" 229 "Librax"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 360 "Rainbow speed"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       802 "THC, Cannabinol" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG4A  209 "Xanax" 605 "PCP (angel dust, phencyclidine)"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG5A  605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DREMGMED  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define EMDRG1A   201 "Valium" 322 "Methamphetamine (speed or ice or cr"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       615 "Homemade drugs" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       818 "Nicotine"
                       900 "Non-Drug reason given for Drug Problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG2A   339 "Amphetamines (speed generically)"
                       430 "Aspirin, Ecotrin, Empirin <OTC>"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 809 "Pills"
                       813 "Cigarettes, tobacco not specified"
                       900 "Non-Drug reason given for Drug Problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG3A   601 "LSD (acid,white lightning)" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG4A   994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG5A   994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMPDRUG   1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIGHELP   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRNKHELP  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTHELP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTEMRG  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTHOSP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRMTDOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTTRMT  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTMHC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTSHG   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTSOP   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRMTSP    4 "AA or NA" 5 "Residential placement"
                       9 "Within myself (self-treatment)" 10 "Church"
                       11 "The street" 12 "Friends" 13 "Court facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKPKCIG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKTRYMJ  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKMJREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYPCP  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKPCPREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYHER  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKHERREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great Risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYCOC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCOCOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCOCREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCRKOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKANSOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKANSREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RK2DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RK5DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKBINGE  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKDIFMJ  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFLSD  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFPCP  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFCOC  1 "Probably imposible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFHER  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PDEN      1 "Segment in a MSA with 1 million or more"
                       2 "Segment in a MSA with fewer than 1 milli"
                       3 "Segment not in a MSA" ;
label define PDEN2     1 "Segment in a MSA with 1 million or more"
                       2 "Segment in a MSA w/ between 250000 to 99"
                       3 "Segment in an MSA with fewer than 250,00"
                       4 "Segment not in a MSA and not in a rural"
                       5 "Segment not in a MSA and in a rural area" ;
label define POPDEN    1 "Segment in a SMSA with 1 million or more"
                       2 "Segment in a SMSA with fewer than 1 mill"
                       3 "Segment not in a SMSA" ;
label define POPDEN2   1 "Segment in a SMSA with 1 million or more"
                       2 "Segment in a SMSA w/betw persons"
                       3 "Segment in a SMSA with fewer than 250000"
                       4 "Segment not in a SMSA and not in a rural"
                       5 "Segment not in a SMSA and in a rural are" ;
label define REGION    1 "Northeast" 2 "North Central" 3 "South" 4 "West" ;
label define DIVISION  1 "New England" 2 "Middle Atlantic"
                       3 "East North Central" 4 "West North Central"
                       5 "South Atlantic" 6 "East South Central"
                       7 "West South Central" 8 "Mountain" 9 "Pacific" ;
label define CHICAGO   1 "Low SES - CHICAGO" 2 "Not Low SES - CHICAGO"
                       9 "Not in CHICAGO" ;
label define DENVER    1 "Low SES - DENVER" 2 "Not Low SES - DENVER"
                       9 "Not in DENVER" ;
label define DC        1 "Low SES - DC" 2 "Not low SES - DC" 9 "NOT IN DC" ;
label define LA        1 "Low SES - LA" 2 "Not Low SES - LA" 9 "Not in LA" ;
label define MIAMI     1 "Low SES - MIAMI" 2 "Not Low SES - MIAMI"
                       9 "Not in MIAMI" ;
label define NEWYORK   1 "Low SES - NEW YORK" 2 "Not Low SES - NEW YORK"
                       9 "Not in NEW YORK" ;
label define IRRACE    1 "American Indian or Alaskan Native"
                       2 "Asian or Pacific Islander" 3 "Black" 4 "White" ;
label define IIRACE    1 "Race from questionnaire"
                       2 "Race from interviewer observation"
                       3 "Race from roster"
                       4 "Race statis imputed using race -Other on"
                       5 "Race statistically imputed, no infor fro" ;
label define IRSEX     1 "Male" 2 "Female" ;
label define IISEX     1 "Sex from questionnaire" 2 "Sex from roster"
                       3 "Sex statistically imputed" ;
label define IIAGE     1 "Age from birthdate"
                       2 "Age from cover of questionnaire"
                       3 "Age from roster"
                       4 "Age statistically imputed using age gr f" ;
label define IRHOIND   1 "Hispanic" 2 "Nonhispanic" ;
label define IIHOIND   1 "Hispanicity derived from questionnaire"
                       2 "Hispanicity derived from roster" ;
label define IRMARIT   1 "Married" 2 "Widowed" 3 "Divorced or Separated"
                       4 "Never Married" 99 "LEGITIMATE SKIP" ;
label define IIMARIT   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRPINSUR  1 "Yes, respondent does have private health"
                       2 "No, respondent does not have private hea" ;
label define IIPINSUR  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRWORKST  1 "Working full-time, 35 hours or more a we"
                       2 "Working part-time, less than 35 hours a"
                       3 "Have job but out: illness/leave/furlough"
                       4 "Unemployed or laid off and looking for w"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       10 "Other, in labor force"
                       11 "Other, not in labor force" ;
label define IIWORKST  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRHSGRAD  1 "Yes, graduated from high school"
                       2 "No, did not graduate from high school" ;
label define IREDUC    0 "No schooling" 1 "First grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year of college"
                       14 "Two years of college" 15 "Three years of college"
                       16 "Four years of college"
                       17 "Graduate/professional school" ;
label define IIEDUC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIHSGRAD  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRHOGRP   1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       99 "LEGITIMATE SKIP" ;
label define IIHOGRP   1 "Hispanic-origin Group taken from questio"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define EDUCCAT2  1 "Less than high school (IREDUC 0-11 and"
                       2 "High school graduate (IREDUC 12 and IRA"
                       3 "Some college (IREDUC 13-15 and IRAGE=>1"
                       4 "College graduate (IREDUC 16-17 and IRAG"
                       5 "12-17 year olds (IRAGE 12-17)" ;
label define EMPSTAT2  1 "Full-time (IRWORKST 1,3 and IRAGE =>18)"
                       2 "Part-time (IRWORKST 2 and IRAGE => 18)"
                       3 "Unemployed (IRWORKST 4,5,10 and IRAGE=>"
                       4 "Other (IRWORKST 6-9,11 and IRAGE =>18)"
                       5 "12-17 year olds (IRAGE 12-17)" ;
label define IRSTMRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used stimulants" ;
label define IROTBRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       9 "Never used smokeless tobacco" ;
label define IRTRNRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used tranquilizers" ;
label define IRSEDRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used sedatives" ;
label define IRMJRC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used marijuana" ;
label define IRMJFQ    1 "Used several times per day in past year"
                       2 "Used daily in past year"
                       3 "Used almost daily in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used several times per month in past yea"
                       6 "Used 1-2 times per month in past year"
                       7 "Used every other month in past year"
                       8 "Used 3-5 times in past year"
                       9 "Used 1-2 times in past year"
                       10 "Never used or did not use in the past ye" ;
label define IIMJFQ    1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IROTBFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIOTBFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSEDFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IISEDFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSTMFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IISTMFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRTRNFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IITRNFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used hallucinogens" ;
label define IRCOCRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used cocaine" ;
label define IRINHRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used inhalants" ;
label define IRANLRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or mare years ago" 9 "Never used analgesics" ;
label define IRALCRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used alcohol" ;
label define IRALCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIALCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRANLFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIANLFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCOCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times per month in past yea"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IICOCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIHALFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRINHFQ   1 "Use daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIINHFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRPCPRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCRKRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used crack" ;
label define IICRKRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSTRRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       9 "Never used anabolic steroids" ;
label define IISTRRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRICERC   1 "Within the past year (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used ice" ;
label define IIICERC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIINHRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIOTBRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHERRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IIHALRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IITRNRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIANLRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IISTMRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IISEDRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IICOCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IIMJRC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIALCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define NDL90REC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE V" ;
label define HALFLAG   0 "Never used (IRHALRC 9)" 1 "Ever used (IRHALRC 1-5)" ;
label define HALYR     0 "Did not use in the past year (IRHALRC ="
                       1 "Used within the past year (IRHALRC 1-3)" ;
label define HALMON    0 "Did not use in the past month (IRHAL = 2"
                       1 "Used within the past month (IRHALRC 1)" ;
label define PCPFLAG   0 "Never" 1 "Ever used (IRPCPRC 1,5)" ;
label define PCPYR     0 "Did not use in the past year (IRPCPRC ="
                       1 "Used within the past year (IRPCPRC 1-3)" ;
label define PCPMON    0 "Did not use in the past month (IRPCPRC ="
                       1 "Used within the past month (IRPCPRC 1)" ;
label define STMFLAG   0 "Never used (IRSTMRC 9)" 1 "Ever used (IRSTMRC 1-5)" ;
label define STMYR     0 "Did not use in the past year (IRSTMRC ="
                       1 "Used within the past year (IRSTMRC 1-3)" ;
label define STMMON    0 "Did not use in the past month (IRSTMRC ="
                       1 "Used within the past month (IRSTMRC 1)" ;
label define SEDFLAG   0 "Never used (IRSEDRC 9)" 1 "Ever used (IRSEDRC 1-5)" ;
label define SEDYR     0 "Did not use in the past year (IRSEDRC 4"
                       1 "Used within the past year (IRSEDRC 1-3)" ;
label define SEDMON    0 "Did not use in the past month (IRSEDRC 2"
                       1 "Used within the past month (IRSEDRC 1)" ;
label define TRQFLAG   0 "Never used (IRTRNRC 9)" 1 "Ever used (IRTRNRC 1-5)" ;
label define TRQYR     0 "Did not use in the past year (IRTRNRC ="
                       1 "Used within the past year (IRTRNRC 1-3)" ;
label define TRQMON    0 "Did not use in the past month (IRTRNRC ="
                       1 "Used within the past month (IRTRNRC 1)" ;
label define ANLFLAG   0 "Never used (IRANLRC 9)" 1 "Ever used (IRANLRC 1-5)" ;
label define ANLYR     0 "Did not use in the past year (IRANLRC ="
                       1 "Used within the past year (IRANLRC 1-3)" ;
label define ANLMON    0 "Did not use in the past month (IRANLRC ="
                       1 "Used within the past month (IRANLRC 1)" ;
label define ALCFLAG   0 "Never used (IRALCRC 9)" 1 "Ever used (IRALCRC 1-5)" ;
label define ALCYR     0 "Did not use in the past year (IRALCRC ="
                       1 "Used within the past year (IRALCRC 1-3)" ;
label define ALCMON    0 "Did not use in the past month (IRALCRC ="
                       1 "Used within the past month (IRALCRC 1)" ;
label define CIGFLAG   0 "Never used (IRCIGRC 9)" 1 "Ever used (IRCIGRC 1-5)" ;
label define CIGYR     0 "Did not use in the past year (IRCIGRC ="
                       1 "Used within the past year (IRCIGRC 1-3)" ;
label define CIGMON    0 "Did not use in the past month (IRCIGRC ="
                       1 "Used within the past month (IRCIGRC 1)" ;
label define SMKFLAG   0 "Never used (IROTBRC 9)" 1 "Ever used (IROTBRC 1-5)" ;
label define SMKYR     0 "Did not use in the past year (IROTBRC ="
                       1 "Used within the past year (IROTBRC 1-3)" ;
label define SMKMON    0 "Did not use in the past month (IROTBRC ="
                       1 "Used within the past month (IROTBRC 1)" ;
label define HERFLAG   0 "Never used (IRHERRC 9)" 1 "Ever used (IRHERRC 1-5)" ;
label define HERYR     0 "Did not use in the past year (IRHERRC ="
                       1 "Used within the past year (IRHERRC 1-3)" ;
label define HERMON    0 "Did not use in the past month (IRHERRC ="
                       1 "Used within the past month (IRHERRC 1)" ;
label define STRFLAG   0 "Never used (IRSTRRC 9)" 1 "Ever used (IRSTRRC 1-5)" ;
label define STRYR     0 "Did not use in the past year (IRSTRRC ="
                       1 "Used within the past year (IRSTRRC 1-3)" ;
label define STRMON    0 "Did not use in the past month (IRSTRRC ="
                       1 "Used within the past month (IRSTRRC 1)" ;
label define MRJFLAG   0 "Never used (IRMJRC 9)" 1 "Ever used (IRMJRC 1-6)" ;
label define MRJYR     0 "Did not use in the past year (IRMJRC 5-6"
                       1 "Used within the past year (IRMJRC 1-4)" ;
label define MRJMON    0 "Did not use in the past month (IRMJRC 3-"
                       1 "Used within the past month (IRMJRC 1-2)" ;
label define COCFLAG   0 "Never used (IRCOCRC 9)" 1 "Ever used (IRCOCRC 1-6)" ;
label define COCYR     0 "Did not use in the past year (IRCOCRC ="
                       1 "Used within the past year (IRCOCRC 1-4)" ;
label define COCMON    0 "Did not use in the past month (IRCOCRC ="
                       1 "Used within the past month (IRCOCRC = 1-" ;
label define CRKFLAG   0 "Never used (IRCRKRC 9)" 1 "Ever used (IRCRKRC 1-6)" ;
label define CRKYR     0 "Did not use in the past year (IRCRKCR ="
                       1 "Used within the past year (IRCRKRC 1-4)" ;
label define CRKMON    0 "Did not use in the past month (IRCRKRC ="
                       1 "Used within the past month (IRCRKRC = 1-" ;
label define INHFLAG   0 "Never used (IRINHRC 9)" 1 "Ever used (IRINHRC 1-6)" ;
label define INHYR     0 "Did not use in the past year (IRINHRC 5-"
                       1 "Used within the past year (IRINHRC 1-4)" ;
label define INHMON    0 "Did not use in the past month (IRINHRC 3"
                       1 "Used within the past month (IRINHRC = 1-" ;
label define NEDFLAG3  0 "Never used (NDL90REC=91,98)"
                       1 "Ever used (NDL90REC=1-9)" ;
label define NEDYR3    0 "Never used (NDL90REC=4-6,9,91,98)"
                       1 "Ever used (NDL90REC=1-3,8)" ;
label define COCYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRCOCFQ 1" ;
label define COCMONF   0 "Did not use monthly/more past year (IRCO"
                       1 "Used monthly or more often past year (IR" ;
label define COCWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRC" ;
label define COCOCCF   0 "Used monthly/more or none in pst yr (IRC"
                       1 "Used past year but less than monthly (IR" ;
label define COCDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define ALCYRF    0 "Never used or not used in past year (IRA"
                       1 "Any use within the past year (IRALCFQ=1-" ;
label define ALCMONF   0 "Did not use monthly/more past year (IRAL"
                       1 "Used monthly or more often past year (IR" ;
label define ALCWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more in past year (IRALCF" ;
label define ALCOCCF   0 "Used monthly/more or none in pst yr (IRA"
                       1 "Used past year but less than monthly (IR" ;
label define ALCDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define ANLYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRANLFQ=1-" ;
label define ANLMONF   0 "Did not use monthly/more past year (IRAN"
                       1 "Used monthly or more often past year (IR" ;
label define ANLWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRA" ;
label define ANLOCCF   0 "Used monthly/more or none in pst yr (IRA"
                       1 "Used past year but less than monthly (IR" ;
label define ANLDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define HALYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRHALFQ= 1" ;
label define HALMONF   0 "Did not use monthly/more past year (IRHA"
                       1 "Used monthly or more often past year (IR" ;
label define HALWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRH" ;
label define HALOCCF   0 "Used monthly/more or none in pst yr (IRH"
                       1 "Used past year but less than monthly (IR" ;
label define HALDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define INHYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRINHFQ=1-" ;
label define INHMONF   0 "Did not use monthly/more past year (IRIN"
                       1 "Used monthly or more often past year (IR" ;
label define INHWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRI" ;
label define INHOCCF   0 "Used monthly/more or none in pst yr (IRI"
                       1 "Used past year but less than monthly (IR" ;
label define INHDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define SEDYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRSEDFQ=1-" ;
label define SEDMONF   0 "Did not use monthly/more past year (IRSE"
                       1 "Used monthly or more often past year (IR" ;
label define SEDWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRS" ;
label define SEDOCCF   0 "Used monthly/more or none in pst yr (IRS"
                       1 "Used past year but less than monthly (IR" ;
label define SEDDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define SMKYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IROTBFQ=1-" ;
label define SMKMONF   0 "Did not use monthly/more past year (IROT"
                       1 "Used monthly or more often past year (IR" ;
label define SMKWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRO" ;
label define SMKOCCF   0 "Used monthly/more or none in pst yr (IRO"
                       1 "Used past year but less than monthly (IR" ;
label define SMKDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define STMYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRSTMFQ=1-" ;
label define STMMONF   0 "Did not use monthly/more past year (IRST"
                       1 "Used monthly or more often past year (IR" ;
label define STMWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year(IRST" ;
label define STMOCCF   0 "Used monthly/more or none in pst yr(IRST"
                       1 "Used past year but less than monthly (IR" ;
label define STMDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define TRQYRF    0 "Never used or did not use in past year ("
                       1 "Any Use within the past year (IRTRNFQ=1-" ;
label define TRQMONF   0 "Did not use monthly/more past year (IRTR"
                       1 "Used monthly or more often past year (IR" ;
label define TRQWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRT" ;
label define TRQOCCF   0 "Used monthly/more or none in pst yr (IRT"
                       1 "Used past year but legs than monthly (IR" ;
label define TRQDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define MRJYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRMJFQ=1-9" ;
label define MRJMONF   0 "Did not use monthly/more past year (IRMJ"
                       1 "Used monthly or more in past year (IRMJF" ;
label define MRJWKF    0 "Did not use weekly/more past year (IRMJF"
                       1 "Used weekly or more in past year (IRMJFQ" ;
label define MRJOCCF   0 "Used monthly/more or none in pst yr (IRM"
                       1 "Used past year but less than monthly (IR" ;
label define MRJDLYF   0 "Did not use daily/almost daily pst yr (I"
                       1 "Used daily/almost daily in past year (IR" ;
label define PSYFLAG2  0 "Never used (ALL SOURCE VARIABLES 9)"
                       1 "Ever used (ANY SOURCE VARIABLE < 9)" ;
label define PSYYR2    0 "Did not use within past year (ALL SOURCE"
                       1 "Used in past year (ANY SOURCE VARIABLE <" ;
label define PSYMON2   0 "Did not use in past month (ALL SOURCE VA"
                       1 "Used in past month (ANY SOURCE VARIABLE" ;
label define SUMFLAG   0 "Never used (ALL SOURCE VARIABLES 0)"
                       1 "Ever used (ANY SOURCE VARIABLE 1)" ;
label define SUMYR     0 "Did not use in past year (ALL SOURCE VAR"
                       1 "Used in past year (ANY SOURCE VARIABLE 1" ;
label define SUMMON    0 "Did not use in past month (ALL SOURCE VA"
                       1 "Used in past month (ANY SOURCE VARIABLE" ;
label define MJOFLAG   0 "Never used MJ/has used both MJ & anoth"
                       1 "Marijuana is only (illicit) drug ever us" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr dru"
                       1 "Marijuana is only (illicit) drug in pas" ;
label define MJOMON2   0 "MJ not used past mnth/Used MJ & othr d"
                       1 "Marijuana only (illicit) drug in past mo" ;
label define IEMFLAG   0 "Never used drug/used only marijuana"
                       1 "Illicit drug except for marijuana are ev" ;
label define IEMYR     0 "Never used drug/used only marijuana past"
                       1 "Illicit drug except for marijuana used p" ;
label define IEMMON    0 "Never used drug/used only marijuana past"
                       1 "Illicit drug except for marijuana used p" ;
label define CATAGE    1 "12-17 years (IRAGE 12-17)"
                       2 "18-25 years (IRAGE 18-25)"
                       3 "26-34 years (IRAGE 26-34)"
                       4 "35+ years (IRAGE > 34)" ;
label define RACE      1 "White (IRRACE = 4 and IRHOIND 2)"
                       2 "Black (IRRACE = 3 and IRHOIND 2)"
                       3 "Hispanic (IRHOIND 1)"
                       4 "Other (IRRACE = 1-2 and IRHOIND 2)" ;
label define IRCIGRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define CATAG2    1 "12-17 years (CATAGE 1)" 2 "18-25 years (CATAGE 2)"
                       3 "26+ years (CATAGE 3-4)" ;
label define AS3READ   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define AS4READ   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define AS5READ   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define AS7READ   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define INHQNC1   1 "QUESTION 1 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC2   2 "QUESTION 2 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC3   3 "QUESTION 3 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC4   4 "QUESTION 4 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC5   5 "BLANK (NO ANSWER)" 98 "BLANK (NO ANSWER)" ;
label define INHQNC6   6 "QUESTION 5 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC7   7 "QUESTION 7 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC8   8 "QUESTION 8 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC9   9 "QUESTION 9 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC10  10 "ALL QUESTIONS WERE CLEAR" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define INHANSY   1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define AS9READ   1 "wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define AS10READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AS11READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AS12READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AS13READ  1 "wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AS15READ  1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HIGHBP    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BPMED     1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WALKPAIN  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TIMEPAIN  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define UPSHOR    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ASTHMA    1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRPSYCH   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEART     1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FLU       1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALLERG    1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HOSPYR    1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SOREYR    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RUNNYYR   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COUGHYR   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PHLEGMYR  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEALTHYR  1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MARITAL   1 "Married" 2 "Widowed" 3 "Divorced or separated"
                       4 "Has never married" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NOMARR    85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKSTAT  1 "Working full-time, 35 hours or more a we"
                       2 "Working part-time, less than 35 hours a"
                       3 "Have job but out: illness/ leave/ furlou"
                       4 "Unemployed or laid off and looking for w"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       10 "Something else (NOT SPECIFIED)"
                       11 "Unable to work - taking care of ill rela"
                       12 "About to start work"
                       13 "Contracts for work (eg Musician)"
                       14 "Welfare (AFDC)"
                       15 "Out of work - Termination - Injury"
                       16 "Just got out of school"
                       17 "Just returned to the United States"
                       18 "Drop out of school" 20 "Family business/no pay"
                       21 "Volunteer" 22 "Babysitting" 23 "Free-lance writer"
                       24 "Internship with/without pay"
                       25 "Student full-time/part-time-self employe"
                       26 "In training with or without pay" 27 "Pregnant"
                       28 "Part-time school/part-time work"
                       29 "Full-time student and or homemaker"
                       30 "Disabled/looking for work/full- and/or p"
                       32 "Did not work/never worked"
                       33 "On leave of absence" 34 "Veterans pension"
                       35 "In school and looking for work"
                       36 "Laid off & applying for disability"
                       37 "Paper route/odd jobs"
                       38 "Waiting to join the military" 39 "Part-time jobs"
                       40 "Retired" 41 "Job injury, workers compensation"
                       42 "In school, working part-time"
                       43 "Working two jobs"
                       44 "In school, but working during break/ sum"
                       45 "Expelled from school/waiting to go to co"
                       46 "College paid by State Industrial"
                       47 "Woodworking-own business" 48 "Self-employed"
                       50 "Seasonal work" 51 "Refuge" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PAYMO     85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER WORKED FOR PAY" 94 "DONT KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PAYYR     185 "BAD DATA Logically assigned"
                       189 "LEGITIMATE SKIP Logically assigned"
                       191 "NEVER WORKED FOR PAY" 194 "DONT KNOW"
                       195 "BAD DATA" 197 "REFUSED" 198 "BLANK (NO ANSWER)"
                       199 "LEGITIMATE SKIP" ;
label define SECTOR    1 "Manufacturing" 2 "Wholesale trade"
                       3 "Retail trade, or" 4 "Something else? (SPECIFY)"
                       5 "AGRICULTURE/FORESTRY/FISHERIES" 6 "MINING"
                       7 "CONSTRUCTION" 8 "TRANSPORTATION" 9 "COMMUNICATIONS"
                       10 "UTILITIES/SANITARY SERVICES"
                       11 "FINANCE/INSURANCE/REAL ESTATE"
                       12 "BUSINESS/REPAIR SERVICES" 13 "PERSONAL SERVICES"
                       14 "ENTERTAINMENT/RECREATION SERVICES"
                       15 "PROFESSIONAL AND RELATED SERVICES"
                       16 "PUBLIC ADMINISTRATION" 17 "BAD DATA"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NO5JOB    89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKDAYS  89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKBLAH  89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CWE       1 "Respondent" 2 "Someone else (NOT SPECIFIED)"
                       3 "Income Contributed Equally" 4 "No one"
                       11 "Head of Household, Employer" 12 "Spouse"
                       13 "Live-in partner, fiancee" 14 "Mother" 15 "Father"
                       16 "Daughter" 17 "Son" 18 "Sister" 19 "Brother"
                       20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative" 24 "Mother-in-law"
                       25 "Father-in-law" 26 "Other female in-laws"
                       27 "Other male in-laws" 28 "Close female friend"
                       29 "Close male friend"
                       30 "Other female acquaintance, roommate"
                       31 "Other male acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father" 35 "Step-daughter"
                       39 "Other step relative,male"
                       40 "Friend (sex unspecified),boarder" 41 "Parents"
                       42 "Grandparents" 43 "Guardian (sex unspecified)"
                       44 "Foster mother, female guardian"
                       45 "Foster father, male guardian"
                       47 "Home care worker or health care aide"
                       50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roomate, sex not specified"
                       53 "Neighbor, sex not specified"
                       54 "Foster parent, sex not specified"
                       56 "Unspecified relationship"
                       59 "Adult children/children"
                       60 "Foster grandchild/foster child" 61 "Siblings"
                       62 "Co-worker" 67 "In-laws,sex not specified"
                       69 "Companion = Code 40"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FULLPART  1 "Full-time" 2 "Part-time"
                       3 "Chief source of income does not work"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CWESECTR  1 "Manufacturing" 2 "Wholesale trade"
                       3 "Retail trade, or" 4 "Something else? (SPECIFY)"
                       5 "AGRICULTURE/FORESTRY/FISHERIES" 6 "MINING"
                       7 "CONSTRUCTION" 8 "TRANSPORTATION" 9 "COMMUNICATIONS"
                       10 "UTILITIES/SANITARY SERVICES"
                       11 "FINANCE/INSURANCE/REAL ESTATE"
                       12 "BUSINESS/REPAIR SERVICES" 13 "PERSONAL SERVICES"
                       14 "ENTERTAINMENT/RECREATION SERVICES"
                       15 "PROFESSIONAL AND RELATED SERVICES"
                       16 "PUBLIC ADMINISTRATION" 17 "BAD DATA"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMTE SKIP" ;
label define EDUC      0 "No schooling" 1 "First Grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh Grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year college"
                       14 "2 years college" 15 "3 years college"
                       16 "4 years college" 17 "Graduate/professional school"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRADHS    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DIPLOMA   1 "High school diploma" 2 "GED certificate"
                       3 "Neither of the above"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ENROLLD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SCHPLANS  1 "Has plans to enroll in a school in futur"
                       2 "Has completed all schooling"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STUDENT   1 "A full-time student" 2 "A part-time student"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SCHDAYS   89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKIPPED   89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ACCID     1 "Yes" 2 "No" 3 "Did not drive in past 12 months"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MOVDAWAY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DORM      85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define MILBASE   85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define HOSP      85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define OTHGPH    85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OTHGPHSP  1 "Own home" 2 "Married"
                       3 "Moved to another home, not specified" 4 "Apartment"
                       5 "Own apartment" 6 "Trailer" 7 "Foster home"
                       8 "Nursing home" 9 "Died" 10 "Lives out of state/city"
                       11 "Staying with a friend" 12 "Job corp"
                       13 "Townhouse" 14 "Overseas/out of country"
                       15 "Lives with his mother/relatives"
                       16 "Relative traveling out of country"
                       17 "With other children" 18 "Group housing in college"
                       19 "Runaway" 20 "Hotel"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SERVICE   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MILSTAT   2 "In a Reserves component"
                       3 "Separated/retired from Reserves or activ"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TELNO     94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MOVES     94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EAP       1 "AM" 2 "PM" 97 "REFUSED" 98 "BLANK(NO ANSWER)" ;
label define UNDINT    1 "No difficulty-no language or reading pr"
                       2 "Just a little difficulty-almost no lang/"
                       3 "Fair amount of difficulty-some lang prob"
                       4 "Difficulty-lang prob" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define COOPINT   1 "Very cooperative" 2 "Fairly cooperative"
                       3 "Not very cooperative" 4 "Openly hostile"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRIVACY   1 "Completely private-no one present/able t"
                       3 "Minor distractions"
                       5 "Person(s) in room or listening 1/3 of th"
                       7 "Serious interruptions more than half the"
                       9 "Constant presence of other person(s)"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PPRES     1 "Response circled" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define SPRES     2 "Response Circled" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define PARPRES   3 "Response Circled" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OARPRES   4 "Response Circled" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OAPRES    5 "Response Circled" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define CPRES     6 "Response Circled" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESNSP  7 "Response circled" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESSPA  11 "Head of household, employer" 12 "Spouse"
                       13 "Live-in partner, fiancee" 14 "Mother" 15 "Father"
                       16 "Daughter" 17 "Son" 18 "Sister" 19 "Brother"
                       20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative"
                       26 "Other female in-laws" 27 "Other male in-laws"
                       28 "Close female friend" 29 "Close male friend"
                       30 "Other female acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father"
                       40 "Friend (sex unspecified), boarder" 41 "Parents"
                       42 "Grandparents" 43 "Guardian (sex unspecified)"
                       44 "Foster mother, female guardian"
                       46 "Governess, nanny or live-in babysitter"
                       47 "Home care worker or health care aide"
                       48 "Housekeeper or maid" 50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roommate, sex not specified"
                       53 "Neighbor, sex not specified" 55 "Escort"
                       56 "Unspecified relationship"
                       58 "Foreign exchange student/student"
                       59 "Adult children/children"
                       60 "Foster grandchild/foster child" 61 "Siblings"
                       62 "Co-worker" 63 "Visitor" 64 "Students"
                       66 "Child (specified or not specified)"
                       71 "Male child" 72 "Customers"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define WHOMARKD  1 "Respondent marked ALL the Answer Sheet r"
                       2 "Interviewer marked All the Answer Sheet"
                       3 "Combination of respondent and F.I ....."
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MILES     99985 "BAD DATA Logically assigned"
                       99989 "LEGITIMATE SKIP Logically assigned"
                       99991 "HAS NEVER DRIVEN A MOTOR VEHICLE"
                       99994 "DONT KNOW" 99995 "BAD DATA" 99997 "REFUSED"
                       99998 "BLANK (NO ANSWER)" 99999 "LEGITIMATE SKIP" ;
label define MOTHER    0 "No (i.e., Legitimate skip or response no" 1 "Yes"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FATHER    0 "No (i.e., Legitimate skip or response no" 1 "Yes"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPMOM   0 "No (i.e., Legitimate skip or response no" 1 "Yes"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPDAD   0 "No (i.e., Legitimate skip or response no" 1 "Yes"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SPOUSE    0 "No (i.e., Legitimate skip or response no" 1 "Yes"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INLAW     0 "No (i.e., Legitimate skip or response no"
                       85 "BAD DATA Logically assigned"
                       93 "RELATION INDICATED, NO COUNT RECORDED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OWNCHILD  0 "No (i.e., Legitimate skip or response no"
                       85 "BAD DATA Logically assigned"
                       93 "RELATION INDICATED, NO COUNT RECORDED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPCHLD  0 "No (i.e., Legitimate skip or response no"
                       85 "BAD DATA Logically assigned"
                       93 "RELATION INDICATED, NO COUNT RECORDED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BROSIS    0 "No (i.e., Legitimate skip or response no"
                       85 "BAD DATA Logically assigned"
                       93 "RELATION INDICATED, NO COUNT RECORDED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHREL    0 "No (i.e., Legitimate skip or response no"
                       85 "BAD DATA Logically assigned"
                       93 "RELATION INDICATED, NO COUNT RECORDED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FRIENDS   0 "No (i.e., Legitimate skip or response no"
                       85 "BAD DATA Logically assigned"
                       93 "RELATION INDICATED, NO COUNT RECORDED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHERNON  0 "No (i.e., Legitimate skip or response no"
                       85 "BAD DATA Logically assigned"
                       93 "RELATION INDICATED, NO COUNT RECORDED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTPEOP   94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NOCHILD   89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (IRAGE<15)" ;
label define CIGREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED CIGARETTES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BAP       1 "AM" 2 "PM" 98 "BLANK (NO ANSWER)" ;
label define LANGVER   1 "English" 2 "Spanish" 98 "BLANK (NO ANSWER)" ;
label define URBARE    1 "Yes" 2 "No"
                       3 "Not in any of the 6 metropolitan areas" ;
label define CENCTY    1 "Yes" 2 "No"
                       3 "Not in any of the 6 metropolitan areas" ;
label define GQTYP     1 "Dormitory" 2 "Other Group Quarters"
                       3 "Not Group Quarters" ;
label define IRHOGRP2  1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       5 "Central American" 6 "South American" 7 "Carribean"
                       99 "LEGITIMATE SKIP Respondent is not hispan" ;
label define IIHOGRP2  1 "Hispanic-Origin Group taken from questio"
                       3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP Respondent is not hispan" ;
label define FAMSKIP   0 "Respondent has other family members in h"
                       1 "Respondent didnt have other family in h" ;
label define WORK      1 "Worked only for an employer"
                       2 "Was self-employed only"
                       3 "Self-employed and working for an employe"
                       4 "Did not work during the month"
                       5 "Did work during the month, logically ass"
                       6 "Did not work during the month LOGICALLY"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WAG1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 98 "BLANK (NO ANSWER)" ;
label define SOC1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SSI1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define WEL1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 98 "BLANK (NO ANSWER)" ;
label define INT1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CHD1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTH1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define WAG2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SOC2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SSI2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WEL2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       98 "BLANK (NO ANSWER)" ;
label define INT2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CHD2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OTH2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FOOD      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       98 "BLANK (NO ANSWER)" ;
label define AWAG1     999985 "BAD DATA Logically assigned"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define ASOC1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define ASSI1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define AWEL1     999985 "BAD DATA Logically assigned"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define AINT1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define ACHD1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define AOTH1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define AWAG2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define ASOC2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define ASSI2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define AWEL2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define AINT2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define ACHD2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define AOTH2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define AFOOD     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define IRWAG1    1 "Yes" 2 "No" ;
label define IRSOC1    1 "Yes" 2 "No" ;
label define IRSSI1    1 "Yes" 2 "No" ;
label define IRWEL1    1 "Yes" 2 "No" ;
label define IRINT1    1 "Yes" 2 "No" ;
label define IRCHD1    1 "Yes" 2 "No" ;
label define IROTH1    1 "Yes" 2 "No" ;
label define IRWAG2    1 "Yes" 2 "No" ;
label define IRSOC2    1 "Yes" 2 "No" ;
label define IRSSI2    1 "Yes" 2 "No" ;
label define IRWEL2    1 "Yes" 2 "No" ;
label define IRINT2    1 "Yes" 2 "No" ;
label define IRCHD2    1 "Yes" 2 "No" ;
label define IROTH2    1 "Yes" 2 "No" ;
label define IRFOOD    1 "Yes" 2 "No" ;
label define IRAWAG1   0 "zero income received" ;
label define IRASOC1   0 "zero income received" ;
label define IRASSI1   0 "Zero income received" ;
label define IRAWEL1   0 "Zero income received" ;
label define IRAINT1   0 "Zero income received" ;
label define IRACHD1   0 "Zero income received" ;
label define IRAOTH1   0 "Zero income received" ;
label define IRAWAG2   0 "Zero income received" ;
label define IRASOC2   0 "zero income received" ;
label define IRASSI2   0 "Zero income received" ;
label define IRAWEL2   0 "Zero income received" ;
label define IRAINT2   0 "Zero income received" ;
label define IRACHD2   0 "Zero income received" ;
label define IRAOTH2   0 "Zero income received" ;
label define IRAFOOD   0 "Zero income received" ;
label define IIWAG1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IISOC1    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IISSI1    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIWEL1    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIINT1    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IICHD1    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIOTH1    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IIWAG2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IISOC2    1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IISSI2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIWEL2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIINT2    1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IICHD2    1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IIOTH2    1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IIFOOD    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IIAWAG1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIASOC1   1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IIASSI1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIAWEL1   1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IIAINT1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIACHD1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIAOTH1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIAWAG2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIASOC2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIASSI2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIAWEL2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIAINT2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIACHD2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIAOTH2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IIAFOOD   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define JOB       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HOURS     985 "BAD DATA Logically assigned" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define WEEKS     94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PUB1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AFDC1     1 "Income from AFDC/ADC" 2 "Income from Other"
                       3 "Income from Both" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PUB2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AFDC2     1 "Income from AFDC/ADC" 2 "Income from Other"
                       3 "Income from Both"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FSTAMP    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PEOPFD    85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WELFARE   1 "Yes, respondent or another fam member on"
                       2 "No, there was no one in the family on we" ;
label define TWOFAM    0 "1 was sampled or 2 unrelated people were"
                       1 "Respondent is 1 of 2 related people samp" ;
label define INDINC    0 "No personal earnings" ;
label define IIINDINC  1 "All personal income sources from questio"
                       3 "At least 1 of sources were stat or logic" ;
label define TOTINC    0 "No family income" ;
label define IITOTINC  1 "All income sources from questionnaire"
                       3 "At least 1 of sources were stat or logic" ;
label define INDCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000 +" ;
label define TOTCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000 +" ;
label define PERINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,999" 5 "$75,000 +" ;
label define FAMINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,999" 5 "$75,000 +" ;
label define PERINC2   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000 +" ;
label define FAMINC2   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000 +" ;
label define FAMINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000 +" 8 "12-17 Years Old" ;
label define PERINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000 +" 8 "12-17 Years Old" ;
label define PRVHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PLYFLAGC  1 "0 drugs" 2 "1 drug" 3 "2 drugs" 4 "3+ drugs" ;
label define PLYYRC    1 "0 drugs" 2 "1 drug" 3 "2 drugs" 4 "3+ drugs" ;
label define PLYMONC   1 "0 drugs" 2 "1 drug" 3 "2 drugs" 4 "3+ drugs" ;
label define WPSTAT    1 "Females w/at least 1 under age 2 (either"
                       2 "Females w/all children age 2 or older"
                       3 "Females w/no children"
                       4 "Females w/missing information about chil" 5 "Males" ;
label define OWNOCONC  1 "Greater than or equal to 50"
                       2 "Greater than or equal to 10, but less th"
                       3 "Less than 10" ;
label define NHBHCONC  1 "Greater than or equal to 50"
                       2 "Greater than or equal to 10, but less th"
                       3 "Less than 10" ;
label define NHBPCONC  1 "Greater than or equal to 50"
                       2 "Greater than or equal to 10, but less th"
                       3 "Less than 10" ;
label define HSPPCONC  1 "Greater than or equal to 50"
                       2 "Greater than or equal to 10, but less th"
                       3 "Less than 10" ;
label define HSPHCONC  1 "Greater than or equal to 50"
                       2 "Greater than or equal to 10, but less th"
                       3 "Less than 10" ;
label define METRO     1 "Chicago Metropolitan area"
                       2 "Denver Metropolitan area"
                       3 "Los Angeles Metropolitan area"
                       4 "Miami Metropolitan area"
                       5 "New York Metropolitan area"
                       6 "Washington, D.C. Metropolitan area ...."
                       9 "Not in any of the 6 Metropolitan areas" ;
label define PROXABLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXYREL  1 "Respondents spouse/live-in partner"
                       2 "Respondents father" 3 "Respondents mother"
                       4 "Respondents brother" 5 "Respondents sister"
                       6 "Other family member, relation not specif"
                       12 "Spouse" 13 "Live-in partner, fiancee" 14 "Mother"
                       15 "Father" 16 "Daughter" 17 "Son" 18 "Sister"
                       19 "Brother" 20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative"
                       26 "Other female in-laws" 27 "Other male in-laws"
                       29 "Close male friend" 32 "Step-mother"
                       33 "Step-father"
                       40 "Friend (sex unspecified), boarder"
                       42 "Grandparents" 43 "Guardian (sex unspecified)"
                       44 "Foster mother, female guardian"
                       45 "Foster father, male guardian"
                       50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXHOME  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PROXJOIN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MEDICARE  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MEDICAID  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CHAMPUS   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OWNHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define GRPHLTIN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINALC  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINDRG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINMNT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WHOANSHI  1 "Sample member" 2 "Proxy"
                       11 "Head of the Household, Employer" 12 "Spouse"
                       13 "Live-in partner, fiancee" 14 "Mother" 15 "Father"
                       16 "Daughter" 17 "Son" 18 "Sister" 19 "Brother"
                       20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative"
                       26 "Other female in-laws" 27 "Other male in-laws"
                       28 "Close female friend" 29 "Close male friend"
                       30 "Other female acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father"
                       40 "Friend (sex unspecified), boarder" 41 "Parents"
                       42 "Grandparents" 44 "Guardian (sex unspecified)"
                       50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roommate, sex not specified"
                       53 "Neighbor, sex not specified"
                       54 "Foster parent, sex not specified"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define WHOANSIN  1 "Sample member" 2 "Pro"
                       11 "Head of the Household, Employer" 12 "Spouse"
                       13 "Live-in partner, fiancee" 14 "Mother" 15 "Father"
                       16 "Daughter" 17 "Son" 18 "Sister" 19 "Brother"
                       20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative" 24 "Mother-in-law"
                       26 "Other female in-laws" 27 "Other male in-laws"
                       28 "Close female friend" 29 "Close male friend"
                       30 "Other female acquaintance, roommate"
                       31 "Other male acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father"
                       39 "Other step relative, male"
                       40 "Friend (sex unspecified), boarder" 41 "Parents"
                       42 "Grandparents" 44 "Foster mother, female guardian"
                       50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roommate, sex not specified"
                       54 "Foster Parent, sex not specified"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NEEDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE V" ;
label define IRINSUR   1 "Yes, respondent does have health insuran"
                       2 "No, respondent does not have health insu" ;
label define IIINSUR   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define HERREC92  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HEROIN Logically imputed"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define IRHERC92  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used heroin" ;
label define IIHERC92  1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRALCAGG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCARG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCABS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCHIG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCJOB  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCMAT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCREL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCFRD  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCTOS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCHOL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCDRU  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCINT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCREM  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCQUI  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCMOR  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCSHO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCALO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRALCBRK  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ 1)" ;
label define IRNOBOOZ  1 "No use of alcohol in the past year"
                       2 "Used alcohol in the past year" ;
label define ANYALC    0 "No" 1 "Yes" ;
label define THREALC   0 "No" 1 "Yes" ;
label define DRUNKYR2  0 "Unknown (DRUNKYR 85,96,97,98)"
                       1 "Drunk more than twice a month (DRUNKYR ="
                       2 "Drunk twice a month or less (DRUNKYR 5-"
                       3 "Never drunk in past year (DRUNKYR 9)" ;
label define TRMTHLP2  0 "No (TRMTHELP=2)" 1 "Yes (TRMTHELP=1)" ;
label define DRNKHLP2  0 "No (DRNKHELP=2)" 1 "Yes (DRNKHELP=1)" ;
label define DRALHELP  0 "No (see note above)"
                       1 "Yes (TRMTHLP2=1 or DRNKHLP2=1)" ;
label define ICEFLAG   0 "Never used (IRICERC 9)" 1 "Ever used (IRICERC 1-6)" ;
label define ICEYR     0 "Did not use in past year (IRICERC=5-6,9)"
                       1 "Used within the past year (IRICERC=1-4)" ;
label define ICEMON    0 "Did not use in the past month (IRICERC="
                       1 "Used within the past month (IRICERC=1-2)" ;
label define MJTOT2    1 "Never used marijuana (MJTOT 81,91)"
                       2 "1-2 times (MJTOT 1)" 3 "3-10 times (MJTOT 2,3)"
                       4 "11-99 times (MJTOT 4,5)"
                       5 "100 or more times (MJTOT 6,7)"
                       6 "Unknown (MJTOT 85,94,97,98)" ;
label define COCTOT2   1 "Never used cocaine (COCTOT 81,91)"
                       2 "1-2 times (COCTOT 1)" 3 "3-10 times (COCTOT 2,3)"
                       4 "11-99 times (COCTOT 4,5)"
                       5 "100 or more times (COCTOT 6,7)"
                       6 "Unknown (COCTOT 85,97,98)" ;
label define MJTOT3    1 "1-2 times (MJTOT2 2)" 2 "3-10 times (MJTOT2 3)"
                       3 "11-99 times (MJTOT2 4)"
                       4 "100 or more times (MJTOT2 5)"
                       5 "Never used marijuana (MJTOT2 1)" ;
label define COCTOT3   0 "Unknown (COCTOT2=6)" 1 "1-2 times (COCTOT2 2)"
                       2 "3-10 times (COCTOT2 3)" 3 "11-99 times (COCTOT2 4)"
                       4 "100 or more times (COCTOT2 5)"
                       5 "Never used cocaine (COCTOT2 1)" ;
label define MJDY30A2  1 "None/never used marijuana (MJDAY30A 0,8"
                       2 "1-2 days (MJDAY30A 1-2)"
                       3 "3-4 days (MJDAY30A 3-4)"
                       4 "5-19 days (MJDAY30A 5-19)"
                       5 "20-30 days (MJDAY30A 20-30)"
                       6 "Unknown (MJDAY30A 85,94,95,98)" ;
label define ALCDAYS2  0 "Unknown (ALCDAYS=85,94,95,97,98)"
                       1 "None or never used alcohol (ALCDAYS 0,81"
                       2 "1-2 days (ALCDAYS 1-2)" 3 "3-4 days (ALCDAYS 3-4)"
                       4 "5-19 days (ALCDAYS 5-19)"
                       5 "20-30 days (ALCDAYS 20-31)" ;
label define MRJMON2   1 "Did not use in past month (MRJMON 0)"
                       2 "Used within the past month (MRJMON 1)" ;
label define ALCMON2   1 "Did not use in the past month (ALCMON 0)"
                       2 "Used within the past month (ALCMON 1)" ;
label define CIGMON2   1 "Did not use in past month (CIGMON 0)"
                       2 "Used within past month (CIGMON 1)" ;
label define LSD2      0 "Never used hallucinogens (LSD 2,81,91,9"
                       1 "Ever used LSD (LSD 1)" ;
label define PEYOTE2   0 "Never used hallucinogens (PEYOTE 2,81,9"
                       1 "Ever used Peyote (PEYOTE 1)" ;
label define MESC2     0 "Never used hallucinogens (MESC 2,81,91,9"
                       1 "Ever used Mescaline (MESC 1)" ;
label define PSILCY2   0 "Never used hallucinogens (PSILCY 2,81,9"
                       1 "Ever used Psilocybin (PSILCY 1)" ;
label define ECSTASY2  0 "Never used hallucinogens (ECSTASY=2,81,9"
                       1 "Ever used Ecstasy (ECSTASY=1)" ;
label define GAS2      0 "Never inhaled (GAS 2,81,91,98)"
                       1 "Ever inhaled (GAS 1,3)" ;
label define LGAS2     0 "Never inhaled (LGAS=2,81,91,98)"
                       1 "Ever inhaled (LGAS=1,3)" ;
label define SPPAINT2  0 "Never inhaled (SPPAINT 2,81,91,98)"
                       1 "Ever inhaled (SPPAINT 1,3)" ;
label define AEROS2    0 "Never inhaled (AEROS 2,81,91,98)"
                       1 "Ever inhaled (AEROS 1,3)" ;
label define GLUE2     0 "Never inhaled (GLUE 2,81,91,98)"
                       1 "Ever inhaled (GLUE 1,3)" ;
label define SOLVENT2  0 "Never inhaled (SOLVENT 2,81,91,98)"
                       1 "Ever inhaled (SOLVENT 1,3)" ;
label define AMYLNIT2  0 "Never inhaled (AMYLNIT 2,81,91,98)"
                       1 "Ever inhaled (AMYLNIT 1,3)" ;
label define ETHER2    0 "Never inhaled (ETHER 2,81,91,98)"
                       1 "Ever inhaled (ETHER 1,3)" ;
label define NITOXID2  0 "Never inhaled (NITOXID 2,81,91,98)"
                       1 "Ever inhaled (NITOXID 1,3)" ;
label define CLEFLU2   0 "Never inhaled (CLEFLU 2,81,91,98)"
                       1 "Ever inhaled (CLEFLU 1,3)" ;
label define COCSNIF2  0 "Never/no use pst 12 mos (COCSNIFF=2,81,8"
                       1 "Sniffed/snorted in past 12 months (COCSN" ;
label define FREEBAS2  0 "Never/no use pst 12 mos (FREEBASE=2,81,8"
                       1 "Freebased in past 12 months (FREEBASE =" ;
label define COCSWAL2  0 "Never/no use pst 12 mos (COCSWAL=2,81,83"
                       1 "Swallowed/drank in past 12 months (COCSW" ;
label define COCIV2    0 "Never/no use past 12 mos (COCIV=2,81,83,"
                       1 "Injected in the past 12 months (COCIV =" ;
label define MJDY30A3  1 "1-2 days (MJDAY30A2 2)" 2 "3-4 days (MJDAY30A2 3)"
                       3 "5-19 days (MJDAY30A2 4)"
                       4 "20-30 days (MJDAY30A2 5)"
                       5 "None or never used marijuana (MJDAY30A21" ;
label define ALCDAYS3  0 "Unknown (ALCDAYS2 .)"
                       1 "None or never used alcohol (ALCDAYS2 1)"
                       2 "1-4 days (ALCDAYS2 2-3)" 3 "5-19 days (ALCDAYS2 4)"
                       4 "20-30 days (ALCDAYS2 5)" ;
label define DRINKER2  0 "Never/no ALC use (ALCMON=0 and DR5DAY=0,"
                       1 "Alcohol use (ALCMON 1 and DR5DAY = 0-30" ;
label define HVYDRK2   0 "Never/no heavy use (DR5DAY=0-4,81,91,93)"
                       1 "Heavy alcohol use (DR5DAY 5-30)" ;
label define AVCIG2    0 "Unknown (AVCIG"
                       1 "None/never smoked cigarettes (AVCIG=81,8"
                       2 "Currently smoke < a pack per day (AV = 1"
                       3 "Currently smoke a pack or more per day ("
                       94 "97,98)" ;
label define RACESEX   0 "Other males and females (SEX=1 or 2 and"
                       1 "White male (SEX = 1 and RACE 1)"
                       2 "Black male (SEX = 1 and RACE 2)"
                       3 "Hispanic male (SEX 1 and RACE 3)"
                       4 "White female (SEX 2 and RACE 1)"
                       5 "Black female (SEX 2 and RACE 2)"
                       6 "Hispanic female (SEX = 2 and RACE 3)" ;
label define NOTMARJ   0 "No (ALL SOURCE VARIABLES 0)"
                       1 "Yes (ANY SOURCE VARIABLES 1)" ;
label define RACESEX2  1 "White male (SEX=1 and RACE=1)"
                       2 "Black male (SEX=1 and RACE=2)"
                       3 "Hispanic male (SEX=1 and RACE=3)"
                       4 "Other male (SEX=1 and RACE=4)"
                       5 "White female (SEX=2 and RACE=1)"
                       6 "Black female (SEX=2 and RACE=2)"
                       7 "Hispanic female (SEX=2 and RACE=3)"
                       8 "Other female (SEX=2 and RACE=4)" ;
label define ALCONLYL  0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=0)" ;
label define ALCONLYY  0 "No" 1 "Yes (ALCYR=1 AND SUMYR=0)" ;
label define ALCONLYM  0 "No" 1 "Yes (ALCMON=1 AND SUMMON=0)" ;
label define ILLONLYL  0 "No" 1 "Yes (SUMFLAG=1 AND ALCFLAG=0)" ;
label define ILLONLYY  0 "No" 1 "Yes (SUMYR=1 AND ALCYR=0)" ;
label define ILLONLYM  0 "No" 1 "Yes (SUMMON=1 AND ALCMON=0)" ;
label define MRJONLYL  0 "No" 1 "Yes (MJOFLAG=1 AND ALCFLAG=0)" ;
label define MRJONLYY  0 "No" 1 "Yes (MJOYR2=1,AND ALCYR=O)" ;
label define MRJONLYM  0 "No" 1 "Yes (MJOMON2=1 AND ALCMON=O)" ;
label define PSYONLYL  0 "No" 1 "Yes (PSYFLAG2=1 AND ALL OTHER SOURCE VAR" ;
label define PSYONLYY  0 "No" 1 "Yes (PSYYR2=1 AND ALL OTHER SOURCE VARS=" ;
label define PSYONLYM  0 "No" 1 "Yes (PSYMON2=1 AND ALL OTHER SOURCE VARS" ;
label define OTHONLYL  0 "No" 1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S" ;
label define OTHONLYY  0 "No" 1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S" ;
label define OTHONLYM  0 "No" 1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S" ;
label define ALCILLL   0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=1)" ;
label define ALCILLY   0 "No" 1 "Yes (ALCYR=1 AND SUMYR=1)" ;
label define ALCILLM   0 "No" 1 "Yes (ALCMON=1 AND SUMMON=1)" ;
label define ALCMRJL   0 "No" 1 "Yes (ALCFLAG, MRJFLAG=1 AND ALL OTHER SO" ;
label define ALCMRJY   0 "No" 1 "Yes (ALCYR AND MRJYR=1 AND ALL OTHER SOU" ;
label define ALCMRJM   0 "No" 1 "Yes (ALCMON & MRJMON=1 AND ALL OTHER S" ;
label define ALCPSYL   0 "No" 1 "Yes (ALCFLAG, PSYFLAG2=1 & ALL OTHER S" ;
label define ALCPSYY   0 "No" 1 "Yes (ALCYR & PSYYR2=1 AND ALL OTHER SO" ;
label define ALCPSYM   0 "No" 1 "Yes (ALCMON & PSYMON2=1 & ALL OTHER" ;
label define ALCOTHL   0 "No" 1 "Yes (ALCFLAG=1 & NEXT 2 VAR=0 & ANY" ;
label define ALCOTHY   0 "No" 1 "Yes (ALCYR=1 & NEXT 2 VAR=0 & ANY OT" ;
label define ALCOTHM   0 "No" 1 "Yes (ALCMON=1 & NEXT 2 VAR=0 & ANY O" ;
label define SUB1LIF   0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2LIF   0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3LIF   0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define SUB1YR    0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2YR    0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3YR    0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define SUB1MON   0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2MON   0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3MON   0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define IRDEP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRARG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRALN     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRANX     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRHLT     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRNTK     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRUPS     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRLSW     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRSSP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRCPE     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IREMG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 1)" ;
label define IRDEP1    111 "Dalmane" 113 "Halcion"
                       120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       122 "Sleep Aid <OTC>" 201 "Valium" 207 "Ativan"
                       208 "Centrax" 209 "Xanax" 211 "Buspar"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,uppers"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 406 "Percodan, Oxycodone"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       423 "Percocet" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       830 "Mad Bull" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP2    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       209 "Xanax" 322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 407 "Demerol" 415 "Codeine"
                       418 "Methadone" 601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       606 "Ecstasy (MDMA), X-TC" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP3    322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid,white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP4    355 "Crystal meth" 601 "LSD (acid,white lightning)"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRDEP5    999 "LEGITIMATE SKIP" ;
label define IRARG1    118 "Pentobarbital, Pentothal, Sodium Pentoth"
                       201 "Valium" 322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       327 "Black Beauty, Black beauties"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       406 "Percodan, Oxycodone"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       423 "Percocet" 502 "Spray paints"
                       506 "Amyl nitrite,poppers, lock rm odoriz"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       830 "Mad Bull" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRARG2    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       415 "Codeine"
                       504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       702 "Heroin" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       999 "LEGITIMATE SKIP" ;
label define IRARG3    322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid,white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRARG4    322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       355 "Crystal meth" 803 "Marijuana" 805 "Cocaine, Coke"
                       807 "Alcohol" 814 "Caffeine" 999 "LEGITIMATE SKIP" ;
label define IRARG5    702 "Heroin" 999 "LEGITIMATE SKIP" ;
label define IRALN1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 207 "Ativan" 211 "Buspar"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 406 "Percodan, Oxycodone" 415 "Codeine"
                       423 "Percocet" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       830 "Mad Bull" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRALN2    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       999 "LEGITIMATE SKIP" ;
label define IRALN3    322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRALN4    322 "Methamphetamine (speed or ice or cr"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       814 "Caffeine" 999 "LEGITIMATE SKIP" ;
label define IRALN5    702 "Heroin" 999 "LEGITIMATE SKIP" ;
label define IRANX1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium" 202 "Librium" 207 "Ativan" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine" 313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       326 "White cross" 328 "Pink hearts" 332 "Ephedrine"
                       335 "Dexatrim" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       357 "Heart-shaped black pills" 358 "20/20"
                       360 "Rainbow speed" 364 "Sudafed, Sinutab"
                       406 "Percodan, Oxycodone" 407 "Demerol"
                       409 "Tylenol with Codeine, Tylenol 3"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       435 "Tylenol <OTC>" 501 "Gasoline or lighter fluids"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       609 "Jimson (sic) weed" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 829 "Robitussin DM"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRANX2    209 "Xanax" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       326 "White cross" 333 "357 Magnum, Magnum 44"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       415 "Codeine"
                       506 "Amyl nitrite,poppers, lock rm odoriz"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecastasy (MDMA), X-TC" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 999 "LEGITIMATE SKIP" ;
label define IRANX3    322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       606 "Ecstasy (MDMA), X-TC"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRANX4    322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       604 "Psilocybin (mushrooms)" 803 "Marijuana"
                       806 "Crack" 813 "Cigarettes, tobacco not specified"
                       814 "Caffeine" 999 "LEGITIMATE SKIP" ;
label define IRANX5    702 "Heroin" 703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRHLT1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       123 "Unisom <OTC>" 201 "Valium"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       333 "357 Magnum, Magnum 44"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       409 "Tylenol with Codeine, Tylenol 3"
                       504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT2    339 "Amphetamines (speed generically)"
                       601 "LSD (acid,white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       818 "Nicotine" 999 "LEGITIMATE SKIP" ;
label define IRHLT3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT4    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid,white lightning)" 803 "Marijuana"
                       814 "Caffeine" 999 "LEGITIMATE SKIP" ;
label define IRHLT5    999 "LEGITIMATE SKIP" ;
label define IRNTK1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       142 "Belladona" 203 "Limbitrol" 209 "Xanax"
                       228 "Amitriptyline" 241 "Prozac"
                       313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       360 "Rainbow speed" 401 "Darvon"
                       406 "Percodan, Oxycodone"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       422 "Motrin" 423 "Percocet" 462 "Norflex"
                       502 "Spray paints"
                       504 "Shoeshine lqd, glue/toluene; Super Glue;"
                       508 "Nitrous oxide, whippets, dentist gas"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC" 609 "sic" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       830 "Mad Bull" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK2    201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       247 "Sinequan"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       360 "Rainbow speed" 407 "Demerol" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK3    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK4    601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       802 "THC, Cannabinol" 803 "Marijuana"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK5    503 "Other aerosol sprays"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS1    118 "Pentobarbital, Pentothal, Sodium Pentoth"
                       203 "Limbitrol" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 360 "Rainbow speed"
                       406 "Percodan, Oxycodone" 415 "Codeine"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       809 "Pills" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 830 "Mad Bull" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS2    209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       502 "Spray paints" 601 "LSD (acid,white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       818 "Nicotine" 999 "LEGITIMATE SKIP" ;
label define IRUPS3    322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth"
                       506 "Amyl nitrite,poppers, lock rm odoriz"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS4    503 "Other aerosol sprays" 803 "Marijuana"
                       805 "Cocaine, Coke" 999 "LEGITIMATE SKIP" ;
label define IRUPS5    999 "LEGITIMATE SKIP" ;
label define IRLSW1    111 "Dalmane" 142 "Belladona" 211 "Buspar"
                       322 "Methamphetamine (speed or ice or cr"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 355 "Crystal meth" 360 "Rainbow speed"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       420 "OTHER Analgesic, NOT SPECIFIED" 422 "Motrin"
                       423 "Percocet" 435 "Tylenol <OTC>"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       609 "Jimson [sic) weed" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW2    322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       360 "Rainbow speed" 524 "White-Out"
                       601 "LSD (acid,white lightning)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW3    322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 503 "Other aerosol sprays"
                       601 "LSD (acid,white lightning)"
                       701 "OTHER Opiates, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW4    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       803 "Marijuana" 999 "LEGITIMATE SKIP" ;
label define IRLSW5    601 "LSD (acid,white lightning)" 999 "LEGITIMATE SKIP" ;
label define IRSSP1    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       207 "Ativan" 211 "Buspar"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 360 "Rainbow speed" 371 "Cogentin"
                       415 "Codeine" 510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)" 603 "Mescaline"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       609 "Jimson (sic) weed" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 830 "Mad Bull" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP2    131 "Haldol" 247 "Sinequan"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid,white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 609 "sic"
                       702 "Heroin" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 818 "Nicotine"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP3    339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 601 "LSD (acid,white lightning)"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRSSP4    807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRSSP5    999 "LEGITIMATE SKIP" ;
label define IRCPE1    201 "Valium" 207 "Ativan" 211 "Buspar"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 355 "Crystal meth" 360 "Rainbow speed"
                       406 "Percodan, Oxycodone"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       420 "OTHER Analgesic, NOT SPECIFIED" 423 "Percocet"
                       502 "Spray paints" 601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       609 "Jimson [sic) weed" 702 "Heroin" 704 "Dope"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRCPE2    120 "OTHER Sedative, NOT SPECIFIED,Downers"
                       201 "Valium"
                       324 "OTHER Stimulant, NOT SPECIFIED,Uppers"
                       339 "Amphetamines (speed generically)" 407 "Demerol"
                       502 "Spray paints"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       818 "Nicotine" 999 "LEGITIMATE SKIP" ;
label define IRCPE3    221 "OTHER Tranquilizer, NOT SPECIFIED" 229 "Librax"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 360 "Rainbow speed"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       802 "THC, Cannabinol" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "Crack" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE4    209 "Xanax" 605 "PCP (angel dust, phencyclidine)"
                       803 "Marijuana" 805 "Cocaine, Coke"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE5    605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       999 "LEGITIMATE SKIP" ;
label define IREMG1    201 "Valium" 322 "Methamphetamine (speed or ice or cr"
                       335 "Dexatrim" 339 "Amphetamines (speed generically)"
                       348 "Crystal" 420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid,white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       615 "Homemade drugs" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       818 "Nicotine" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IREMG2    339 "Amphetamines (speed generically)"
                       430 "Aspirin, Ecotrin, Empirin <OTC>"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "Crack"
                       807 "Alcohol" 809 "Pills" 999 "LEGITIMATE SKIP" ;
label define IREMG3    601 "LSD (acid,white lightning)" 999 "LEGITIMATE SKIP" ;
label define IREMG4    999 "LEGITIMATE SKIP" ;
label define IREMG5    999 "LEGITIMATE SKIP" ;
label define IRAS13    1 "Never used any of the substances listed"
                       2 "Used one or more of the listed substance" ;
label define ANYPROB   0 "No" 1 "Yes" ;
label define TWOPROB   0 "No" 1 "Yes" ;
label define THREPROB  0 "No" 1 "Yes" ;
label define DEPCIG2   0 "No" 1 "Yes" ;
label define DEPALC2   0 "No" 1 "Yes" ;
label define DEPMRJ2   0 "No" 1 "Yes" ;
label define DEPCOC2   0 "No" 1 "Yes" ;
label define ARGCIG2   0 "No" 1 "Yes" ;
label define ARGALC2   0 "No" 1 "Yes" ;
label define ARGMRJ2   0 "No" 1 "Yes" ;
label define ARGCOC2   0 "No" 1 "Yes" ;
label define ALNCIG2   0 "No" 1 "Yes" ;
label define ALNALC2   0 "No" 1 "Yes" ;
label define ALNMRJ2   0 "No" 1 "Yes" ;
label define ALNCOC2   0 "No" 1 "Yes" ;
label define ANXCIG2   0 "No" 1 "Yes" ;
label define ANXALC2   0 "No" 1 "Yes" ;
label define ANXMRJ2   0 "No" 1 "Yes" ;
label define ANXCOC2   0 "No" 1 "Yes" ;
label define HLTCIG2   0 "No" 1 "Yes" ;
label define HLTALC2   0 "No" 1 "Yes" ;
label define HLTMRJ2   0 "No" 1 "Yes" ;
label define HLTCOC2   0 "No" 1 "Yes" ;
label define NTKCIG2   0 "No" 1 "Yes" ;
label define NTKALC2   0 "No" 1 "Yes" ;
label define NTKMRJ2   0 "No" 1 "Yes" ;
label define NTKCOC2   0 "No" 1 "Yes" ;
label define UPSCIG2   0 "No" 1 "Yes" ;
label define UPSALC2   0 "No" 1 "Yes" ;
label define UPSMRJ2   0 "No" 1 "Yes" ;
label define UPSCOC2   0 "No" 1 "Yes" ;
label define LSWCIG2   0 "No" 1 "Yes" ;
label define LSWALC2   0 "No" 1 "Yes" ;
label define LSWMRJ2   0 "No" 1 "Yes" ;
label define LSWCOC2   0 "No" 1 "Yes" ;
label define SSPCIG2   0 "No" 1 "Yes" ;
label define SSPALC2   0 "No" 1 "Yes" ;
label define SSPMRJ2   0 "No" 1 "Yes" ;
label define SSPCOC2   0 "No" 1 "Yes" ;
label define CPECIG2   0 "No" 1 "Yes" ;
label define CPEALC2   0 "No" 1 "Yes" ;
label define CPEMRJ2   0 "No" 1 "Yes" ;
label define CPECOC2   0 "No" 1 "Yes" ;
label define EMCIG2    0 "No" 1 "Yes" ;
label define EMALC2    0 "No" 1 "Yes" ;
label define EMMRJ2    0 "No" 1 "Yes" ;
label define EMCOC2    0 "No" 1 "Yes" ;
label define PRB1CIG   0 "No" 1 "Yes" ;
label define PRB1ALC   0 "No" 1 "Yes" ;
label define PRB1MRJ   0 "No" 1 "Yes" ;
label define PRB1COC   0 "No" 1 "Yes" ;
label define PRB2CIG   0 "No" 1 "Yes" ;
label define PRB2ALC   0 "No" 1 "Yes" ;
label define PRB2MRJ   0 "No" 1 "Yes" ;
label define PRB2COC   0 "No" 1 "Yes" ;
label define PRB3CIG   0 "No" 1 "Yes" ;
label define PRB3ALC   0 "No" 1 "Yes" ;
label define PRB3MRJ   0 "No" 1 "Yes" ;
label define PRB3COC   0 "No" 1 "Yes" ;
label define IRCDCIG   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in p"
                       99 "LEGITIMATE SKIP" ;
label define IRCDALC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in p"
                       99 "LEGITIMATE SKIP" ;
label define IRCDMJ    1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in p"
                       99 "LEGITIMATE SKIP" ;
label define IRCDCOC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in p"
                       99 "LEGITIMATE SKIP" ;
label define IREFCIG   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for s"
                       99 "LEGITIMATE SKIP" ;
label define IREFALC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for s"
                       99 "LEGITIMATE SKIP" ;
label define IREFMJ    1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for s"
                       99 "LEGITIMATE SKIP" ;
label define IREFCOC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for s"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCIG   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past y"
                       99 "LEGITIMATE SKIP" ;
label define IRUDALC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past y"
                       99 "LEGITIMATE SKIP" ;
label define IRUDMJ    1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past y"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCOC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past y"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCIG   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug u"
                       99 "LEGITIMATE SKIP" ;
label define IRDPALC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug u"
                       99 "LEGITIMATE SKIP" ;
label define IRDPMJ    1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug u"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCOC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug u"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCIG   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the"
                       99 "LEGITIMATE SKIP" ;
label define IRWSALC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the"
                       99 "LEGITIMATE SKIP" ;
label define IRWSMJ    1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCOC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the"
                       99 "LEGITIMATE SKIP" ;
label define AVCIG3    0 "None/never/< pack a day (AVCIG=1-3,81,89"
                       1 "Currently smoke a pack or more per day (" ;
label define ALCPROBS  0 "No" 1 "Yes" ;
label define MJPROBS   0 "No" 1 "Yes" ;
label define COCPROBS  0 "No" 1 "Yes" ;
label define CIGPROBS  0 "No" 1 "Yes" ;
label define QC06      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define QC09      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       98 "BLANK (NO ANSWER)" ;
label define AL02      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 91 "NEVER USED ALCOHOL"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SE04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define TR04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define ST04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define ST07      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       91 "NEVER USED ANY AMPHETAMINE WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define AN04      1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define MJ04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 91 "NEVER USED MARIJUANA"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define IN04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 91 "NEVER USED INHALANTS"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CC04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 91 "NEVER USED COCAINE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CC10      1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago" 91 "NEVER USED COCAINE"
                       93 "NEVER USED COCAINE WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CC11      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 91 "NEVER USED CRACK"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LS05      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 91 "NEVER USED HALLUCINOGENS"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LS08      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 91 "NEVER USED PCP"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HE04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 91 "NEVER USED HEROIN"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HE07      1 "within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago" 91 "NEVER USED HEROIN"
                       93 "NEVER USED HEROIN WITH A NEEDLE (HERNEED"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DR08      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       91 "NEVER USED ANY DRUG FOR NONMEDICAL REASO"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SP04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       91 "Never used the smokable form of amphetam"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SP08      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       91 "NEVER USED STEROIDS IN LIFE"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHDOSP1  1 "Shoplifting (SP15a)"
                       2 "Other larceny or theft (SP15b)"
                       3 "Property damage (incl vandalism)(SP15c)"
                       4 "Motor vehicle theft (SP15d)" 5 "Robbery (SP15e, i)"
                       6 "Breaking and entering, burglary (SP15f)"
                       7 "Hitting someone or physically fighting"
                       8 "Hurting someone enough to need medical a"
                       9 "Other assault, battery"
                       10 "Driving under influence of alcohol/drugs"
                       11 "Selling illegal drugs (SP15k)"
                       12 "Drug offense (except sales) involving ma"
                       13 "Other drug-related offense"
                       14 "Drunkeness or other liquor law violation"
                       15 "Forcible rape"
                       16 "Murder, homicide or nonnegligent manslau"
                       17 "Other offenses against persons" 18 "Arson"
                       19 "Nondestructive property offenses, e.g. f"
                       20 "Prostitution or commercialized sex"
                       21 "Weapons offenses"
                       22 "Violation of court order, parole, probat"
                       23 "Public order offenses"
                       24 "Juvenile status offenses"
                       25 "Immigration law violation" 26 "Traffic violations"
                       27 "Other offenses, NOT SPECIFIED"
                       85 "BAD DATA (i.e., cannot be classified)."
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHDOSP2  1 "Shoplifting (SP15a)"
                       2 "Other larceny or theft (SP15b)"
                       3 "Property damage (incl vandalism) (SP15c)"
                       5 "Robbery (SP15e, i)"
                       7 "Hitting someone or physically fighting ("
                       10 "Driving under influence of alcohol/drugs"
                       11 "Selling illegal drugs (SP15k)"
                       12 "Drug offense (except sales) involving ma"
                       13 "Other drug-related offenses"
                       14 "Drunkeness or other liquor law violation"
                       16 "Murder, homicide or nonnegligent manslau"
                       19 "Nondestructive property offenses, such a"
                       21 "Weapons offenses" 23 "Public order offenses"
                       24 "Juvenile status offenses"
                       25 "Immigration law violation" 26 "Traffic violations"
                       85 "BAD DATA (i.e., cannot be classified)."
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCWAY2   0 "Never/no use pst 12 mos (COCWAY=2,3,81,8"
                       1 "Used other ways past 12 months (COCWAY=1" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.\n
****************************************************************/

/*
replace CWEOCC2 = . if (CWEOCC2 >= 994 )
replace ROCCUP2 = . if (ROCCUP2 >= 994 )
replace BUSINES2 = . if (BUSINES2 >= 990 )
replace CWEBUS2 = . if (CWEBUS2 >= 990 )
replace SNUFREC = . if (SNUFREC >= 81 )
replace ALCREC = . if (ALCREC >= 81 )
replace SEDREC = . if (SEDREC >= 81 )
replace TRANREC = . if (TRANREC >= 81 )
replace STIMREC = . if (STIMREC >= 81 )
replace STNDLREC = . if (STNDLREC >= 81 )
replace ANALREC = . if (ANALREC >= 81 )
replace MJREC = . if (MJREC >= 81 )
replace INHREC = . if (INHREC >= 81 )
replace CRAKREC = . if (CRAKREC >= 81 )
replace COCREC = . if (COCREC >= 81 )
replace CONDLREC = . if (CONDLREC >= 81 )
replace PCPREC = . if (PCPREC >= 81 )
replace HALLREC = . if (HALLREC >= 81 )
replace HERREC = . if (HERREC >= 81 )
replace HRNDLREC = . if (HRNDLREC >= 81 )
replace GNNDLREC = . if (GNNDLREC >= 81 )
replace ICEREC = . if (ICEREC >= 81 )
replace STERREC = . if (STERREC >= 81 )
replace ALCSED = . if (ALCSED >= 81 )
replace ALCTRAN = . if (ALCTRAN >= 81 )
replace ALCSTM = . if (ALCSTM >= 81 )
replace ALCANAL = . if (ALCANAL >= 81 )
replace ALCMJ = . if (ALCMJ >= 81 )
replace ALCINH = . if (ALCINH >= 81 )
replace ALCCOC = . if (ALCCOC >= 81 )
replace ALCHAL = . if (ALCHAL >= 81 )
replace ALCOPT = . if (ALCOPT >= 81 )
replace ALCNONE = . if (ALCNONE >= 81 )
replace CIGTRY = . if (CIGTRY >= 185 )
replace CIGAGE = . if (CIGAGE >= 181 )
replace CIGYRS = . if (CIGYRS >= 181 )
replace ALCTRY = . if (ALCTRY >= 181 )
replace ALCAGE = . if (ALCAGE >= 181 )
replace SEDAGE = . if (SEDAGE >= 181 )
replace TRANAGE = . if (TRANAGE >= 181 )
replace STIMAGE = . if (STIMAGE >= 181 )
replace ANALAGE = . if (ANALAGE >= 181 )
replace MJOPP = . if (MJOPP >= 181 )
replace MJAGE = . if (MJAGE >= 181 )
replace INHAGE = . if (INHAGE >= 181 )
replace COCOPP = . if (COCOPP >= 181 )
replace COCAGE = . if (COCAGE >= 181 )
replace HALLOPP = . if (HALLOPP >= 181 )
replace HALLAGE = . if (HALLAGE >= 181 )
replace HEROPP = . if (HEROPP >= 181 )
replace HERAGE = . if (HERAGE >= 181 )
replace STEROPP = . if (STEROPP >= 181 )
replace STERAGE = . if (STERAGE >= 181 )
replace OTHTOB = . if (OTHTOB >= 81 )
replace ALCPAT = . if (ALCPAT >= 81 )
replace SEDYRFRQ = . if (SEDYRFRQ >= 81 )
replace TRNYRFRQ = . if (TRNYRFRQ >= 81 )
replace STMYRFRQ = . if (STMYRFRQ >= 81 )
replace ANLYRFRQ = . if (ANLYRFRQ >= 81 )
replace MJYRFREQ = . if (MJYRFREQ >= 81 )
replace INHYRFRQ = . if (INHYRFRQ >= 81 )
replace COCYRFRQ = . if (COCYRFRQ >= 81 )
replace HALYRFRQ = . if (HALYRFRQ >= 81 )
replace CIG5PK = . if (CIG5PK >= 81 )
replace PACKS = . if (PACKS >= 81 )
replace AVCIG = . if (AVCIG >= 81 )
replace CIGTIME = . if (CIGTIME >= 9981 )
replace ALCDAYS = . if (ALCDAYS >= 81 )
replace NODR30A = . if (NODR30A >= 81 )
replace DR5DAY = . if (DR5DAY >= 81 )
replace MODR30A = . if (MODR30A >= 81 )
replace MODR30DY = . if (MODR30DY >= 81 )
replace DRUNKYR = . if (DRUNKYR >= 81 )
replace ALCBEER = . if (ALCBEER >= 81 )
replace ALCWINE = . if (ALCWINE >= 81 )
replace ALCLIQR = . if (ALCLIQR >= 81 )
replace ALCVARY = . if (ALCVARY >= 81 )
replace NOBOOZYR = . if (NOBOOZYR >= 81 )
replace ALCAGGR = . if (ALCAGGR >= 81 )
replace ALCARGUM = . if (ALCARGUM >= 81 )
replace ALCABSNT = . if (ALCABSNT >= 81 )
replace ALCHIGH = . if (ALCHIGH >= 81 )
replace ALCJOB = . if (ALCJOB >= 81 )
replace ALCMATCD = . if (ALCMATCD >= 81 )
replace ALCRELCD = . if (ALCRELCD >= 81 )
replace ALCFRDCD = . if (ALCFRDCD >= 81 )
replace ALCTOSS = . if (ALCTOSS >= 81 )
replace ALCHOLIC = . if (ALCHOLIC >= 81 )
replace ALCDRUNK = . if (ALCDRUNK >= 81 )
replace ALCINTOX = . if (ALCINTOX >= 81 )
replace ALCREM = . if (ALCREM >= 81 )
replace ALCQUICK = . if (ALCQUICK >= 81 )
replace ALCMORN = . if (ALCMORN >= 81 )
replace ALCSHOOK = . if (ALCSHOOK >= 81 )
replace ALCALONE = . if (ALCALONE >= 81 )
replace ALCBRKPM = . if (ALCBRKPM >= 81 )
replace BUTISOL = . if (BUTISOL >= 81 )
replace BUTICAPS = . if (BUTICAPS >= 81 )
replace AMYTAL = . if (AMYTAL >= 81 )
replace MEBARAL = . if (MEBARAL >= 81 )
replace PLACIDYL = . if (PLACIDYL >= 81 )
replace DORIDEN = . if (DORIDEN >= 81 )
replace NOLUDAR = . if (NOLUDAR >= 81 )
replace NEMBUTAL = . if (NEMBUTAL >= 81 )
replace SECONAL = . if (SECONAL >= 81 )
replace TUINAL = . if (TUINAL >= 81 )
replace DALMANE = . if (DALMANE >= 81 )
replace RESTORIL = . if (RESTORIL >= 81 )
replace HALCION = . if (HALCION >= 81 )
replace AMOBARB = . if (AMOBARB >= 81 )
replace PHENOBAR = . if (PHENOBAR >= 81 )
replace METHAQ = . if (METHAQ >= 81 )
replace CHHYD = . if (CHHYD >= 81 )
replace PENTOB = . if (PENTOB >= 81 )
replace SECOB = . if (SECOB >= 81 )
replace SEDNOSP = . if (SEDNOSP >= 81 )
replace SEDNEWA = . if (SEDNEWA >= 981 )
replace SEDNEWB = . if (SEDNEWB >= 981 )
replace SEDNEWC = . if (SEDNEWC >= 991 )
replace SEDNEWD = . if (SEDNEWD >= 991 )
replace SEDNEWE = . if (SEDNEWE >= 181 )
replace SEDDKNAM = . if (SEDDKNAM >= 81 )
replace NOSEDAT = . if (NOSEDAT >= 81 )
replace SEDTOT = . if (SEDTOT >= 81 )
replace VALIUM = . if (VALIUM >= 81 )
replace LIBRIUM = . if (LIBRIUM >= 81 )
replace LIMBTROL = . if (LIMBTROL >= 81 )
replace MENRIUM = . if (MENRIUM >= 81 )
replace SERAX = . if (SERAX >= 81 )
replace TRANXENE = . if (TRANXENE >= 81 )
replace ATIVAN = . if (ATIVAN >= 81 )
replace CENTRAX = . if (CENTRAX >= 81 )
replace XANAX = . if (XANAX >= 81 )
replace PAXIPAM = . if (PAXIPAM >= 81 )
replace BUSPAR = . if (BUSPAR >= 81 )
replace MILTOWN = . if (MILTOWN >= 81 )
replace EQUANIL = . if (EQUANIL >= 81 )
replace DEPROL = . if (DEPROL >= 81 )
replace VISTAR = . if (VISTAR >= 81 )
replace ATARAX = . if (ATARAX >= 81 )
replace DURRAX = . if (DURRAX >= 81 )
replace DIAZEPAM = . if (DIAZEPAM >= 81 )
replace SKLY = . if (SKLY >= 81 )
replace MEPROB = . if (MEPROB >= 81 )
replace TRNOSP = . if (TRNOSP >= 81 )
replace TRNEWA = . if (TRNEWA >= 991 )
replace TRNEWB = . if (TRNEWB >= 181 )
replace TRNEWC = . if (TRNEWC >= 181 )
replace TRNEWD = . if (TRNEWD >= 181 )
replace TRNEWE = . if (TRNEWE >= 181 )
replace TRDKNAM = . if (TRDKNAM >= 81 )
replace NOTRANQ = . if (NOTRANQ >= 81 )
replace TRANTOT = . if (TRANTOT >= 81 )
replace DEXED = . if (DEXED >= 81 )
replace DEXAMYL = . if (DEXAMYL >= 81 )
replace ESKAT = . if (ESKAT >= 81 )
replace BENZ = . if (BENZ >= 81 )
replace BIPHET = . if (BIPHET >= 81 )
replace DESOXYN = . if (DESOXYN >= 81 )
replace TENUATE = . if (TENUATE >= 81 )
replace TEPANIL = . if (TEPANIL >= 81 )
replace DIDREX = . if (DIDREX >= 81 )
replace PLEGINE = . if (PLEGINE >= 81 )
replace PRELUDIN = . if (PRELUDIN >= 81 )
replace IONAMIN = . if (IONAMIN >= 81 )
replace FASTIN = . if (FASTIN >= 81 )
replace PONDIMIN = . if (PONDIMIN >= 81 )
replace VORANIL = . if (VORANIL >= 81 )
replace SANOREX = . if (SANOREX >= 81 )
replace MAZANOR = . if (MAZANOR >= 81 )
replace RITALIN = . if (RITALIN >= 81 )
replace CYLERT = . if (CYLERT >= 81 )
replace DETAMP = . if (DETAMP >= 81 )
replace METHI = . if (METHI >= 81 )
replace METHAMP = . if (METHAMP >= 81 )
replace OBLA = . if (OBLA >= 81 )
replace STIMNOSP = . if (STIMNOSP >= 81 )
replace STIMNEWA = . if (STIMNEWA >= 981 )
replace STIMNEWB = . if (STIMNEWB >= 991 )
replace STIMNEWC = . if (STIMNEWC >= 991 )
replace STIMNEWD = . if (STIMNEWD >= 181 )
replace STIMNEWE = . if (STIMNEWE >= 181 )
replace STMDKNAM = . if (STMDKNAM >= 81 )
replace NOSTIMS = . if (NOSTIMS >= 81 )
replace STIMTOT = . if (STIMTOT >= 81 )
replace STNEEDLE = . if (STNEEDLE >= 81 )
replace DARVON = . if (DARVON >= 81 )
replace DOLENE = . if (DOLENE >= 81 )
replace SK65A = . if (SK65A >= 81 )
replace WYGESIC = . if (WYGESIC >= 81 )
replace LEVODRO = . if (LEVODRO >= 81 )
replace PERCODAN = . if (PERCODAN >= 81 )
replace DEMEROL = . if (DEMEROL >= 81 )
replace DILAUD = . if (DILAUD >= 81 )
replace TYLCOD = . if (TYLCOD >= 81 )
replace PHENCOD = . if (PHENCOD >= 81 )
replace TALWIN = . if (TALWIN >= 81 )
replace TALWINNX = . if (TALWINNX >= 81 )
replace TALACEN = . if (TALACEN >= 81 )
replace PROPOXY = . if (PROPOXY >= 81 )
replace CODEINE = . if (CODEINE >= 81 )
replace ANILERID = . if (ANILERID >= 81 )
replace MORPHINE = . if (MORPHINE >= 81 )
replace METHDON = . if (METHDON >= 81 )
replace STADOL = . if (STADOL >= 81 )
replace ANLNOSP = . if (ANLNOSP >= 81 )
replace ANALNEWA = . if (ANALNEWA >= 981 )
replace ANALNEWB = . if (ANALNEWB >= 991 )
replace ANALNEWC = . if (ANALNEWC >= 181 )
replace ANALNEWD = . if (ANALNEWD >= 181 )
replace ANALNEWE = . if (ANALNEWE >= 181 )
replace ANLDKNAM = . if (ANLDKNAM >= 81 )
replace ANALNONE = . if (ANALNONE >= 81 )
replace ANALTOT = . if (ANALTOT >= 81 )
replace MJTOT = . if (MJTOT >= 81 )
replace MJDAY30A = . if (MJDAY30A >= 81 )
replace MJAV30A = . if (MJAV30A >= 81 )
replace MJAV30B = . if (MJAV30B >= 81 )
replace MJAMT30A = . if (MJAMT30A >= 81 )
replace MJJOINT = . if (MJJOINT >= 81 )
replace MJPIPE = . if (MJPIPE >= 81 )
replace MJBAKE = . if (MJBAKE >= 81 )
replace MJCHEW = . if (MJCHEW >= 81 )
replace MJWAY = . if (MJWAY >= 81 )
replace GAS = . if (GAS >= 81 )
replace LGAS = . if (LGAS >= 81 )
replace SPPAINT = . if (SPPAINT >= 81 )
replace AEROS = . if (AEROS >= 81 )
replace GLUE = . if (GLUE >= 81 )
replace SOLVENT = . if (SOLVENT >= 81 )
replace AMYLNIT = . if (AMYLNIT >= 81 )
replace ETHER = . if (ETHER >= 81 )
replace NITOXID = . if (NITOXID >= 81 )
replace CLEFLU = . if (CLEFLU >= 81 )
replace INHNOSP = . if (INHNOSP >= 81 )
replace INHDKNAM = . if (INHDKNAM >= 81 )
replace INHTOT = . if (INHTOT >= 81 )
replace GAS30A = . if (GAS30A >= 81 )
replace LGAS30A = . if (LGAS30A >= 81 )
replace SPPAN30A = . if (SPPAN30A >= 81 )
replace AEROS30A = . if (AEROS30A >= 81 )
replace GLUE30A = . if (GLUE30A >= 81 )
replace SOLVN30A = . if (SOLVN30A >= 81 )
replace AMLNT30A = . if (AMLNT30A >= 81 )
replace ETHER30A = . if (ETHER30A >= 81 )
replace NOX30A = . if (NOX30A >= 81 )
replace CLFL30A = . if (CLFL30A >= 81 )
replace IN30NOSP = . if (IN30NOSP >= 81 )
replace INH30NO = . if (INH30NO >= 81 )
replace INHDY30A = . if (INHDY30A >= 81 )
replace INHEFF = . if (INHEFF >= 81 )
replace INHPO = . if (INHPO >= 81 )
replace INHNEWA = . if (INHNEWA >= 981 )
replace INHNEWB = . if (INHNEWB >= 981 )
replace INHNEWC = . if (INHNEWC >= 181 )
replace INHNEWD = . if (INHNEWD >= 181 )
replace INHNEWE = . if (INHNEWE >= 181 )
replace INNEW30A = . if (INNEW30A >= 981 )
replace INNEW30B = . if (INNEW30B >= 981 )
replace INNEW30C = . if (INNEW30C >= 181 )
replace INNEW30D = . if (INNEW30D >= 181 )
replace INNEW30E = . if (INNEW30E >= 181 )
replace COCTOT = . if (COCTOT >= 81 )
replace COCUS30A = . if (COCUS30A >= 81 )
replace CRKAM30A = . if (CRKAM30A >= 181 )
replace CRAKBUCK = . if (CRAKBUCK >= 9981 )
replace COCAM30A = . if (COCAM30A >= 81 )
replace COCBUCK = . if (COCBUCK >= 9981 )
replace COCSNIFF = . if (COCSNIFF >= 81 )
replace COCSWAL = . if (COCSWAL >= 81 )
replace COCIV = . if (COCIV >= 81 )
replace FREEBASE = . if (FREEBASE >= 81 )
replace COCWAY = . if (COCWAY >= 81 )
replace LSD = . if (LSD >= 81 )
replace PEYOTE = . if (PEYOTE >= 81 )
replace MESC = . if (MESC >= 81 )
replace PSILCY = . if (PSILCY >= 81 )
replace PCP = . if (PCP >= 81 )
replace ECSTASY = . if (ECSTASY >= 81 )
replace HALNOSP = . if (HALNOSP >= 81 )
replace HALNEWA = . if (HALNEWA >= 981 )
replace HALNEWB = . if (HALNEWB >= 981 )
replace HALNEWC = . if (HALNEWC >= 181 )
replace HALNEWD = . if (HALNEWD >= 181 )
replace HALNEWE = . if (HALNEWE >= 181 )
replace HALDKNAM = . if (HALDKNAM >= 81 )
replace HALLTOT = . if (HALLTOT >= 81 )
replace HAL30USE = . if (HAL30USE >= 81 )
replace HERTOT = . if (HERTOT >= 81 )
replace HER30USE = . if (HER30USE >= 81 )
replace HERNEEDL = . if (HERNEEDL >= 81 )
replace CDCIG = . if (CDCIG >= 81 )
replace CDALC = . if (CDALC >= 81 )
replace CDSED = . if (CDSED >= 81 )
replace CDTRAN = . if (CDTRAN >= 81 )
replace CDSTM = . if (CDSTM >= 81 )
replace CDANAL = . if (CDANAL >= 81 )
replace CDMJ = . if (CDMJ >= 81 )
replace CDINH = . if (CDINH >= 81 )
replace CDCOC = . if (CDCOC >= 81 )
replace CDHALL = . if (CDHALL >= 81 )
replace CDHER = . if (CDHER >= 81 )
replace CDOTHOP = . if (CDOTHOP >= 81 )
replace CDNONE = . if (CDNONE >= 81 )
replace UCDCIG = . if (UCDCIG >= 81 )
replace UCDALC = . if (UCDALC >= 81 )
replace UCDSED = . if (UCDSED >= 81 )
replace UCDTRAN = . if (UCDTRAN >= 81 )
replace UCDSTM = . if (UCDSTM >= 81 )
replace UCDANAL = . if (UCDANAL >= 81 )
replace UCDMJ = . if (UCDMJ >= 81 )
replace UCDINH = . if (UCDINH >= 81 )
replace UCDCOC = . if (UCDCOC >= 81 )
replace UCDHALL = . if (UCDHALL >= 81 )
replace UCDHER = . if (UCDHER >= 81 )
replace UCDOTHOP = . if (UCDOTHOP >= 81 )
replace UCDNONE = . if (UCDNONE >= 81 )
replace EFFCIG = . if (EFFCIG >= 81 )
replace EFFALC = . if (EFFALC >= 81 )
replace EFFSED = . if (EFFSED >= 81 )
replace EFFTRAN = . if (EFFTRAN >= 81 )
replace EFFSTM = . if (EFFSTM >= 81 )
replace EFFANAL = . if (EFFANAL >= 81 )
replace EFFMJ = . if (EFFMJ >= 81 )
replace EFFINH = . if (EFFINH >= 81 )
replace EFFCOC = . if (EFFCOC >= 81 )
replace EFFHALL = . if (EFFHALL >= 81 )
replace EFFHER = . if (EFFHER >= 81 )
replace EFFOTHOP = . if (EFFOTHOP >= 81 )
replace EFFNONE = . if (EFFNONE >= 81 )
replace UDAYCIG = . if (UDAYCIG >= 81 )
replace UDAYALC = . if (UDAYALC >= 81 )
replace UDAYSED = . if (UDAYSED >= 81 )
replace UDAYTRAN = . if (UDAYTRAN >= 81 )
replace UDAYSTM = . if (UDAYSTM >= 81 )
replace UDAYANAL = . if (UDAYANAL >= 81 )
replace UDAYMJ = . if (UDAYMJ >= 81 )
replace UDAYINH = . if (UDAYINH >= 81 )
replace UDAYCOC = . if (UDAYCOC >= 81 )
replace UDAYHALL = . if (UDAYHALL >= 81 )
replace UDAYHER = . if (UDAYHER >= 81 )
replace UDAYOTH = . if (UDAYOTH >= 81 )
replace UDAYNONE = . if (UDAYNONE >= 81 )
replace DEPCIG = . if (DEPCIG >= 81 )
replace DEPALC = . if (DEPALC >= 81 )
replace DEPSED = . if (DEPSED >= 81 )
replace DEPTRAN = . if (DEPTRAN >= 81 )
replace DEPSTM = . if (DEPSTM >= 81 )
replace DEPANAL = . if (DEPANAL >= 81 )
replace DEPMJ = . if (DEPMJ >= 81 )
replace DEPINH = . if (DEPINH >= 81 )
replace DEPCOC = . if (DEPCOC >= 81 )
replace DEPHALL = . if (DEPHALL >= 81 )
replace DEPHER = . if (DEPHER >= 81 )
replace DEPOTHOP = . if (DEPOTHOP >= 81 )
replace DEPNONE = . if (DEPNONE >= 81 )
replace WSCIG = . if (WSCIG >= 81 )
replace WSALC = . if (WSALC >= 81 )
replace WSSED = . if (WSSED >= 81 )
replace WSTRAN = . if (WSTRAN >= 81 )
replace WSSTM = . if (WSSTM >= 81 )
replace WSANAL = . if (WSANAL >= 81 )
replace WSMJ = . if (WSMJ >= 81 )
replace WSINH = . if (WSINH >= 81 )
replace WSCOC = . if (WSCOC >= 81 )
replace WSHALL = . if (WSHALL >= 13 )
replace WSHER = . if (WSHER >= 81 )
replace WSOTHOP = . if (WSOTHOP >= 81 )
replace WSNONE = . if (WSNONE >= 81 )
replace GNNDLLIF = . if (GNNDLLIF >= 81 )
replace GNNDLSED = . if (GNNDLSED >= 81 )
replace GNNDLTRA = . if (GNNDLTRA >= 81 )
replace GNNDLSTM = . if (GNNDLSTM >= 81 )
replace GNNDLANL = . if (GNNDLANL >= 81 )
replace GNNDLMJ = . if (GNNDLMJ >= 81 )
replace GNNDLINH = . if (GNNDLINH >= 81 )
replace GNNDLCOC = . if (GNNDLCOC >= 81 )
replace GNNDLHAL = . if (GNNDLHAL >= 81 )
replace GNNDLHER = . if (GNNDLHER >= 81 )
replace GNNDLOPT = . if (GNNDLOPT >= 81 )
replace GNNDLNON = . if (GNNDLNON >= 81 )
replace GNNDLSHR = . if (GNNDLSHR >= 81 )
replace DRUGTEST = . if (DRUGTEST >= 81 )
replace TESTPOS = . if (TESTPOS >= 81 )
replace ICELIFE = . if (ICELIFE >= 81 )
replace STERTOT = . if (STERTOT >= 81 )
replace BOOKED = . if (BOOKED >= 81 )
replace NOBOOKYR = . if (NOBOOKYR >= 181 )
replace BKLARCNY = . if (BKLARCNY >= 81 )
replace BKBURGL = . if (BKBURGL >= 81 )
replace BKAGASLT = . if (BKAGASLT >= 81 )
replace BKSMASLT = . if (BKSMASLT >= 81 )
replace BKMVTHFT = . if (BKMVTHFT >= 81 )
replace BKROB = . if (BKROB >= 81 )
replace BKRAPE = . if (BKRAPE >= 81 )
replace BKMURDER = . if (BKMURDER >= 81 )
replace BKARSON = . if (BKARSON >= 81 )
replace BKDRVINF = . if (BKDRVINF >= 81 )
replace BKDRUNK = . if (BKDRUNK >= 81 )
replace BKDRUG = . if (BKDRUG >= 81 )
replace BKPROS = . if (BKPROS >= 81 )
replace BKVANDAL = . if (BKVANDAL >= 81 )
replace BKOTHOFF = . if (BKOTHOFF >= 81 )
replace NOTBKED = . if (NOTBKED >= 81 )
replace PROBATON = . if (PROBATON >= 81 )
replace PAROLE = . if (PAROLE >= 81 )
replace STRSTEAL = . if (STRSTEAL >= 81 )
replace OTHSTEAL = . if (OTHSTEAL >= 81 )
replace DAMAGE = . if (DAMAGE >= 81 )
replace CARSTEAL = . if (CARSTEAL >= 81 )
replace FORCEMON = . if (FORCEMON >= 81 )
replace BREAKIN = . if (BREAKIN >= 81 )
replace PHYFIGHT = . if (PHYFIGHT >= 81 )
replace HURTBAD = . if (HURTBAD >= 81 )
replace GUNMONEY = . if (GUNMONEY >= 81 )
replace DRUNKDRV = . if (DRUNKDRV >= 81 )
replace SOLDDRUG = . if (SOLDDRUG >= 81 )
replace OTHDOING = . if (OTHDOING >= 81 )
replace SPNEWA = . if (SPNEWA >= 985 )
replace SPNEWB = . if (SPNEWB >= 997 )
replace SPNEWC = . if (SPNEWC >= 997 )
replace SPNEWD = . if (SPNEWD >= 997 )
replace SPNEWE = . if (SPNEWE >= 181 )
replace AS13NONE = . if (AS13NONE >= 81 )
replace DRDEPRSS = . if (DRDEPRSS >= 81 )
replace DEPDRG1A = . if (DEPDRG1A >= 989 )
replace DEPDRG2A = . if (DEPDRG2A >= 994 )
replace DEPDRG3A = . if (DEPDRG3A >= 994 )
replace DEPDRG4A = . if (DEPDRG4A >= 994 )
replace DEPDRG5A = . if (DEPDRG5A >= 181 )
replace DRARGUM = . if (DRARGUM >= 81 )
replace ARGDRG1A = . if (ARGDRG1A >= 989 )
replace ARGDRG2A = . if (ARGDRG2A >= 985 )
replace ARGDRG3A = . if (ARGDRG3A >= 994 )
replace ARGDRG4A = . if (ARGDRG4A >= 994 )
replace ARGDRG5A = . if (ARGDRG5A >= 994 )
replace DRALONE = . if (DRALONE >= 81 )
replace ALNDRG1A = . if (ALNDRG1A >= 989 )
replace ALNDRG2A = . if (ALNDRG2A >= 994 )
replace ALNDRG3A = . if (ALNDRG3A >= 994 )
replace ALNDRG4A = . if (ALNDRG4A >= 994 )
replace ALNDRG5A = . if (ALNDRG5A >= 994 )
replace DRANX = . if (DRANX >= 81 )
replace ANXDRG1A = . if (ANXDRG1A >= 989 )
replace ANXDRG2A = . if (ANXDRG2A >= 994 )
replace ANXDRG3A = . if (ANXDRG3A >= 994 )
replace ANXDRG4A = . if (ANXDRG4A >= 994 )
replace ANXDRG5A = . if (ANXDRG5A >= 994 )
replace DRHEALTH = . if (DRHEALTH >= 81 )
replace HLTDRG1A = . if (HLTDRG1A >= 989 )
replace HLTDRG2A = . if (HLTDRG2A >= 994 )
replace HLTDRG3A = . if (HLTDRG3A >= 994 )
replace HLTDRG4A = . if (HLTDRG4A >= 994 )
replace HLTDRG5A = . if (HLTDRG5A >= 994 )
replace DRNTHINK = . if (DRNTHINK >= 81 )
replace NTKDRG1A = . if (NTKDRG1A >= 989 )
replace NTKDRG2A = . if (NTKDRG2A >= 994 )
replace NTKDRG3A = . if (NTKDRG3A >= 994 )
replace NTKDRG4A = . if (NTKDRG4A >= 994 )
replace NTKDRG5A = . if (NTKDRG5A >= 994 )
replace DRUPSET = . if (DRUPSET >= 81 )
replace UPSDRG1A = . if (UPSDRG1A >= 989 )
replace UPSDRG2A = . if (UPSDRG2A >= 994 )
replace UPSDRG3A = . if (UPSDRG3A >= 994 )
replace UPSDRG4A = . if (UPSDRG4A >= 994 )
replace UPSDRG5A = . if (UPSDRG5A >= 994 )
replace DRLSWORK = . if (DRLSWORK >= 81 )
replace LSWDRG1A = . if (LSWDRG1A >= 989 )
replace LSWDRG2A = . if (LSWDRG2A >= 994 )
replace LSWDRG3A = . if (LSWDRG3A >= 994 )
replace LSWDRG4A = . if (LSWDRG4A >= 994 )
replace LSWDRG5A = . if (LSWDRG5A >= 994 )
replace DRSUSPIC = . if (DRSUSPIC >= 81 )
replace SSPDRG1A = . if (SSPDRG1A >= 989 )
replace SSPDRG2A = . if (SSPDRG2A >= 994 )
replace SSPDRG3A = . if (SSPDRG3A >= 994 )
replace SSPDRG4A = . if (SSPDRG4A >= 994 )
replace SSPDRG5A = . if (SSPDRG5A >= 994 )
replace DRCOPE = . if (DRCOPE >= 81 )
replace CPEDRG1A = . if (CPEDRG1A >= 989 )
replace CPEDRG2A = . if (CPEDRG2A >= 994 )
replace CPEDRG3A = . if (CPEDRG3A >= 994 )
replace CPEDRG4A = . if (CPEDRG4A >= 994 )
replace CPEDRG5A = . if (CPEDRG5A >= 994 )
replace DREMGMED = . if (DREMGMED >= 81 )
replace EMDRG1A = . if (EMDRG1A >= 989 )
replace EMDRG2A = . if (EMDRG2A >= 994 )
replace EMDRG3A = . if (EMDRG3A >= 994 )
replace EMDRG4A = . if (EMDRG4A >= 994 )
replace EMDRG5A = . if (EMDRG5A >= 994 )
replace EMPDRUG = . if (EMPDRUG >= 81 )
replace CIGHELP = . if (CIGHELP >= 81 )
replace DRNKHELP = . if (DRNKHELP >= 81 )
replace TRMTHELP = . if (TRMTHELP >= 81 )
replace TRMTEMRG = . if (TRMTEMRG >= 81 )
replace TRMTHOSP = . if (TRMTHOSP >= 81 )
replace TRMTDOC = . if (TRMTDOC >= 81 )
replace TRMTTRMT = . if (TRMTTRMT >= 81 )
replace TRMTMHC = . if (TRMTMHC >= 81 )
replace TRMTSHG = . if (TRMTSHG >= 81 )
replace TRMTSOP = . if (TRMTSOP >= 81 )
replace TRMTSP = . if (TRMTSP >= 81 )
replace RSKPKCIG = . if (RSKPKCIG >= 81 )
replace RSKTRYMJ = . if (RSKTRYMJ >= 81 )
replace RSKMJOCC = . if (RSKMJOCC >= 81 )
replace RSKMJREG = . if (RSKMJREG >= 81 )
replace RKTRYPCP = . if (RKTRYPCP >= 81 )
replace RKPCPREG = . if (RKPCPREG >= 81 )
replace RKTRYHER = . if (RKTRYHER >= 81 )
replace RKHERREG = . if (RKHERREG >= 81 )
replace RKTRYCOC = . if (RKTRYCOC >= 81 )
replace RKCOCOCC = . if (RKCOCOCC >= 81 )
replace RKCOCREG = . if (RKCOCREG >= 81 )
replace RKCRKOCC = . if (RKCRKOCC >= 81 )
replace RKANSOCC = . if (RKANSOCC >= 81 )
replace RKANSREG = . if (RKANSREG >= 81 )
replace RK2DRINK = . if (RK2DRINK >= 81 )
replace RK5DRINK = . if (RK5DRINK >= 81 )
replace RSKBINGE = . if (RSKBINGE >= 81 )
replace RSKDIFMJ = . if (RSKDIFMJ >= 81 )
replace RKDIFLSD = . if (RKDIFLSD >= 81 )
replace RKDIFPCP = . if (RKDIFPCP >= 81 )
replace RKDIFCOC = . if (RKDIFCOC >= 81 )
replace RKDIFHER = . if (RKDIFHER >= 81 )
replace OVESTR = . if (OVESTR >= 9981 )
replace CHICAGO = . if (CHICAGO >= 9 )
replace DENVER = . if (DENVER >= 9 )
replace DC = . if (DC >= 9 )
replace LA = . if (LA >= 9 )
replace MIAMI = . if (MIAMI >= 9 )
replace NEWYORK = . if (NEWYORK >= 9 )
replace IRAGE = . if (IRAGE >= 181 )
replace IRMARIT = . if (IRMARIT >= 81 )
replace IIMARIT = . if (IIMARIT >= 9 )
replace IRWORKST = . if (IRWORKST >= 81 )
replace IREDUC = . if (IREDUC >= 81 )
replace IRHOGRP = . if (IRHOGRP >= 81 )
replace IIHOGRP = . if (IIHOGRP >= 9 )
replace IRSTMRC = . if (IRSTMRC >= 9 )
replace IROTBRC = . if (IROTBRC >= 9 )
replace IRTRNRC = . if (IRTRNRC >= 9 )
replace IRSEDRC = . if (IRSEDRC >= 9 )
replace IRMJRC = . if (IRMJRC >= 9 )
replace IRMJFQ = . if (IRMJFQ >= 10 )
replace IROTBFQ = . if (IROTBFQ >= 9 )
replace IRSEDFQ = . if (IRSEDFQ >= 9 )
replace IRSTMFQ = . if (IRSTMFQ >= 9 )
replace IRTRNFQ = . if (IRTRNFQ >= 9 )
replace IRHALRC = . if (IRHALRC >= 9 )
replace IRCOCRC = . if (IRCOCRC >= 9 )
replace IRINHRC = . if (IRINHRC >= 9 )
replace IRANLRC = . if (IRANLRC >= 9 )
replace IRALCRC = . if (IRALCRC >= 9 )
replace IRALCFQ = . if (IRALCFQ >= 9 )
replace IRANLFQ = . if (IRANLFQ >= 9 )
replace IRCOCFQ = . if (IRCOCFQ >= 9 )
replace IRHALFQ = . if (IRHALFQ >= 9 )
replace IRINHFQ = . if (IRINHFQ >= 9 )
replace IRPCPRC = . if (IRPCPRC >= 9 )
replace IRCRKRC = . if (IRCRKRC >= 9 )
replace IRSTRRC = . if (IRSTRRC >= 9 )
replace IRICERC = . if (IRICERC >= 9 )
replace IRHERRC = . if (IRHERRC >= 9 )
replace NDL90REC = . if (NDL90REC >= 81 )
replace IRCIGRC = . if (IRCIGRC >= 9 )
replace AS3READ = . if (AS3READ >= 81 )
replace AS4READ = . if (AS4READ >= 81 )
replace AS5READ = . if (AS5READ >= 81 )
replace AS7READ = . if (AS7READ >= 81 )
replace INHQNC1 = . if (INHQNC1 >= 81 )
replace INHQNC2 = . if (INHQNC2 >= 81 )
replace INHQNC3 = . if (INHQNC3 >= 81 )
replace INHQNC4 = . if (INHQNC4 >= 81 )
replace INHQNC5 = . if (INHQNC5 >= 81 )
replace INHQNC6 = . if (INHQNC6 >= 81 )
replace INHQNC7 = . if (INHQNC7 >= 81 )
replace INHQNC8 = . if (INHQNC8 >= 81 )
replace INHQNC9 = . if (INHQNC9 >= 81 )
replace INHQNC10 = . if (INHQNC10 >= 81 )
replace INHANSY = . if (INHANSY >= 81 )
replace AS9READ = . if (AS9READ >= 81 )
replace AS10READ = . if (AS10READ >= 81 )
replace AS11READ = . if (AS11READ >= 81 )
replace AS12READ = . if (AS12READ >= 81 )
replace AS13READ = . if (AS13READ >= 81 )
replace AS15READ = . if (AS15READ >= 81 )
replace HIGHBP = . if (HIGHBP >= 81 )
replace BPMED = . if (BPMED >= 81 )
replace WALKPAIN = . if (WALKPAIN >= 81 )
replace TIMEPAIN = . if (TIMEPAIN >= 81 )
replace UPSHOR = . if (UPSHOR >= 81 )
replace ASTHMA = . if (ASTHMA >= 81 )
replace TRPSYCH = . if (TRPSYCH >= 81 )
replace HEART = . if (HEART >= 81 )
replace FLU = . if (FLU >= 81 )
replace ALLERG = . if (ALLERG >= 81 )
replace HOSPYR = . if (HOSPYR >= 81 )
replace SOREYR = . if (SOREYR >= 81 )
replace RUNNYYR = . if (RUNNYYR >= 81 )
replace COUGHYR = . if (COUGHYR >= 81 )
replace PHLEGMYR = . if (PHLEGMYR >= 81 )
replace HEALTHYR = . if (HEALTHYR >= 81 )
replace MARITAL = . if (MARITAL >= 81 )
replace NOMARR = . if (NOMARR >= 81 )
replace WORKSTAT = . if (WORKSTAT >= 81 )
replace PAYMO = . if (PAYMO >= 81 )
replace PAYYR = . if (PAYYR >= 181 )
replace SECTOR = . if (SECTOR >= 17 )
replace NO5JOB = . if (NO5JOB >= 81 )
replace WORKDAYS = . if (WORKDAYS >= 81 )
replace WORKBLAH = . if (WORKBLAH >= 81 )
replace CWE = . if (CWE >= 85 )
replace FULLPART = . if (FULLPART >= 81 )
replace CWESECTR = . if (CWESECTR >= 17 )
replace EDUC = . if (EDUC >= 81 )
replace GRADHS = . if (GRADHS >= 81 )
replace DIPLOMA = . if (DIPLOMA >= 81 )
replace ENROLLD = . if (ENROLLD >= 81 )
replace SCHPLANS = . if (SCHPLANS >= 81 )
replace STUDENT = . if (STUDENT >= 81 )
replace SCHDAYS = . if (SCHDAYS >= 81 )
replace SKIPPED = . if (SKIPPED >= 81 )
replace ACCID = . if (ACCID >= 81 )
replace MOVDAWAY = . if (MOVDAWAY >= 81 )
replace DORM = . if (DORM >= 81 )
replace MILBASE = . if (MILBASE >= 81 )
replace HOSP = . if (HOSP >= 81 )
replace OTHGPH = . if (OTHGPH >= 81 )
replace OTHGPHSP = . if (OTHGPHSP >= 81 )
replace SERVICE = . if (SERVICE >= 81 )
replace MILSTAT = . if (MILSTAT >= 81 )
replace TELNO = . if (TELNO >= 81 )
replace MOVES = . if (MOVES >= 81 )
replace EAP = . if (EAP >= 81 )
replace UNDINT = . if (UNDINT >= 81 )
replace COOPINT = . if (COOPINT >= 81 )
replace PRIVACY = . if (PRIVACY >= 81 )
replace PPRES = . if (PPRES >= 81 )
replace SPRES = . if (SPRES >= 81 )
replace PARPRES = . if (PARPRES >= 81 )
replace OARPRES = . if (OARPRES >= 81 )
replace OAPRES = . if (OAPRES >= 81 )
replace CPRES = . if (CPRES >= 81 )
replace OPRESNSP = . if (OPRESNSP >= 81 )
replace OPRESSPA = . if (OPRESSPA >= 81 )
replace WHOMARKD = . if (WHOMARKD >= 81 )
replace ETIME = . if (ETIME >= 9900 )
replace MOTHER = . if (MOTHER >= 81 )
replace FATHER = . if (FATHER >= 81 )
replace STEPMOM = . if (STEPMOM >= 81 )
replace STEPDAD = . if (STEPDAD >= 81 )
replace SPOUSE = . if (SPOUSE >= 81 )
replace INLAW = . if (INLAW >= 81 )
replace OWNCHILD = . if (OWNCHILD >= 81 )
replace STEPCHLD = . if (STEPCHLD >= 81 )
replace BROSIS = . if (BROSIS >= 81 )
replace OTHREL = . if (OTHREL >= 81 )
replace FRIENDS = . if (FRIENDS >= 81 )
replace OTHERNON = . if (OTHERNON >= 81 )
replace TOTPEOP = . if (TOTPEOP >= 81 )
replace NOCHILD = . if (NOCHILD >= 81 )
replace CIGREC = . if (CIGREC >= 81 )
replace BTIME = . if (BTIME >= 9981 )
replace BAP = . if (BAP >= 81 )
replace LANGVER = . if (LANGVER >= 81 )
replace ENCPSU = . if (ENCPSU >= 181 )
replace ENCSEG = . if (ENCSEG >= 9981 )
replace IRHOGRP2 = . if (IRHOGRP2 >= 81 )
replace WORK = . if (WORK >= 81 )
replace WAG1 = . if (WAG1 >= 81 )
replace SOC1 = . if (SOC1 >= 81 )
replace SSI1 = . if (SSI1 >= 81 )
replace WEL1 = . if (WEL1 >= 81 )
replace INT1 = . if (INT1 >= 81 )
replace CHD1 = . if (CHD1 >= 81 )
replace OTH1 = . if (OTH1 >= 81 )
replace WAG2 = . if (WAG2 >= 81 )
replace SOC2 = . if (SOC2 >= 81 )
replace SSI2 = . if (SSI2 >= 81 )
replace WEL2 = . if (WEL2 >= 81 )
replace INT2 = . if (INT2 >= 81 )
replace CHD2 = . if (CHD2 >= 81 )
replace OTH2 = . if (OTH2 >= 81 )
replace FOOD = . if (FOOD >= 81 )
replace IRASOC1 = . if (IRASOC1 >= 9981 )
replace IRASSI1 = . if (IRASSI1 >= 9981 )
replace IRAWEL1 = . if (IRAWEL1 >= 9981 )
replace IRAINT1 = . if (IRAINT1 >= 9981 )
replace IRACHD1 = . if (IRACHD1 >= 9981 )
replace IRAOTH1 = . if (IRAOTH1 >= 9981 )
replace IRASOC2 = . if (IRASOC2 >= 9981 )
replace IRASSI2 = . if (IRASSI2 >= 9981 )
replace IRAWEL2 = . if (IRAWEL2 >= 9981 )
replace IRAINT2 = . if (IRAINT2 >= 9981 )
replace IRACHD2 = . if (IRACHD2 >= 9981 )
replace JOB = . if (JOB >= 81 )
replace HOURS = . if (HOURS >= 985 )
replace WEEKS = . if (WEEKS >= 81 )
replace PUB1 = . if (PUB1 >= 81 )
replace AFDC1 = . if (AFDC1 >= 81 )
replace PUB2 = . if (PUB2 >= 81 )
replace AFDC2 = . if (AFDC2 >= 81 )
replace FSTAMP = . if (FSTAMP >= 81 )
replace PEOPFD = . if (PEOPFD >= 81 )
replace INDCAT = . if (INDCAT >= 81 )
replace TOTCAT = . if (TOTCAT >= 81 )
replace PRVHLTIN = . if (PRVHLTIN >= 81 )
replace METRO = . if (METRO >= 9 )
replace PROXABLE = . if (PROXABLE >= 81 )
replace PROXYREL = . if (PROXYREL >= 81 )
replace PROXHOME = . if (PROXHOME >= 81 )
replace PROXJOIN = . if (PROXJOIN >= 81 )
replace MEDICARE = . if (MEDICARE >= 81 )
replace MEDICAID = . if (MEDICAID >= 81 )
replace CHAMPUS = . if (CHAMPUS >= 81 )
replace OWNHLTIN = . if (OWNHLTIN >= 81 )
replace GRPHLTIN = . if (GRPHLTIN >= 81 )
replace HLTINALC = . if (HLTINALC >= 81 )
replace HLTINDRG = . if (HLTINDRG >= 81 )
replace HLTINMNT = . if (HLTINMNT >= 81 )
replace WHOANSHI = . if (WHOANSHI >= 81 )
replace WHOANSIN = . if (WHOANSIN >= 81 )
replace NEEDLREC = . if (NEEDLREC >= 81 )
replace HERREC92 = . if (HERREC92 >= 81 )
replace IRHERC92 = . if (IRHERC92 >= 9 )
replace VESTR = . if (VESTR >= 9981 )
replace BIRMON = . if (BIRMON >= 81 )
replace BIRYEAR = . if (BIRYEAR >= 9981 )
replace IRALCAGG = . if (IRALCAGG >= 81 )
replace IRALCARG = . if (IRALCARG >= 81 )
replace IRALCABS = . if (IRALCABS >= 81 )
replace IRALCHIG = . if (IRALCHIG >= 81 )
replace IRALCJOB = . if (IRALCJOB >= 81 )
replace IRALCMAT = . if (IRALCMAT >= 81 )
replace IRALCREL = . if (IRALCREL >= 81 )
replace IRALCFRD = . if (IRALCFRD >= 81 )
replace IRALCTOS = . if (IRALCTOS >= 81 )
replace IRALCHOL = . if (IRALCHOL >= 81 )
replace IRALCDRU = . if (IRALCDRU >= 81 )
replace IRALCINT = . if (IRALCINT >= 81 )
replace IRALCREM = . if (IRALCREM >= 81 )
replace IRALCQUI = . if (IRALCQUI >= 81 )
replace IRALCMOR = . if (IRALCMOR >= 81 )
replace IRALCSHO = . if (IRALCSHO >= 81 )
replace IRALCALO = . if (IRALCALO >= 81 )
replace IRALCBRK = . if (IRALCBRK >= 81 )
replace IRDEP = . if (IRDEP >= 81 )
replace IRARG = . if (IRARG >= 81 )
replace IRALN = . if (IRALN >= 81 )
replace IRANX = . if (IRANX >= 81 )
replace IRHLT = . if (IRHLT >= 81 )
replace IRNTK = . if (IRNTK >= 81 )
replace IRUPS = . if (IRUPS >= 81 )
replace IRLSW = . if (IRLSW >= 81 )
replace IRSSP = . if (IRSSP >= 81 )
replace IRCPE = . if (IRCPE >= 81 )
replace IREMG = . if (IREMG >= 81 )
replace IRDEP1 = . if (IRDEP1 >= 998 )
replace IRDEP2 = . if (IRDEP2 >= 999 )
replace IRDEP3 = . if (IRDEP3 >= 99 )
replace IRDEP4 = . if (IRDEP4 >= 999 )
replace IRDEP5 = . if (IRDEP5 >= 999 )
replace IRARG1 = . if (IRARG1 >= 998 )
replace IRARG2 = . if (IRARG2 >= 998 )
replace IRARG3 = . if (IRARG3 >= 998 )
replace IRARG4 = . if (IRARG4 >= 999 )
replace IRARG5 = . if (IRARG5 >= 998 )
replace IRALN1 = . if (IRALN1 >= 998 )
replace IRALN2 = . if (IRALN2 >= 998 )
replace IRALN3 = . if (IRALN3 >= 998 )
replace IRALN4 = . if (IRALN4 >= 998 )
replace IRALN5 = . if (IRALN5 >= 999 )
replace IRANX1 = . if (IRANX1 >= 998 )
replace IRANX2 = . if (IRANX2 >= 999 )
replace IRANX3 = . if (IRANX3 >= 999 )
replace IRANX4 = . if (IRANX4 >= 999 )
replace IRANX5 = . if (IRANX5 >= 999 )
replace IRHLT1 = . if (IRHLT1 >= 998 )
replace IRHLT2 = . if (IRHLT2 >= 998 )
replace IRHLT3 = . if (IRHLT3 >= 999 )
replace IRHLT4 = . if (IRHLT4 >= 999 )
replace IRHLT5 = . if (IRHLT5 >= 998 )
replace IRNTK1 = . if (IRNTK1 >= 998 )
replace IRNTK2 = . if (IRNTK2 >= 998 )
replace IRNTK3 = . if (IRNTK3 >= 998 )
replace IRNTK4 = . if (IRNTK4 >= 998 )
replace IRNTK5 = . if (IRNTK5 >= 998 )
replace IRUPS1 = . if (IRUPS1 >= 998 )
replace IRUPS2 = . if (IRUPS2 >= 998 )
replace IRUPS3 = . if (IRUPS3 >= 998 )
replace IRUPS4 = . if (IRUPS4 >= 998 )
replace IRUPS5 = . if (IRUPS5 >= 181 )
replace IRLSW1 = . if (IRLSW1 >= 998 )
replace IRLSW2 = . if (IRLSW2 >= 998 )
replace IRLSW3 = . if (IRLSW3 >= 998 )
replace IRLSW4 = . if (IRLSW4 >= 998 )
replace IRLSW5 = . if (IRLSW5 >= 998 )
replace IRSSP1 = . if (IRSSP1 >= 998 )
replace IRSSP2 = . if (IRSSP2 >= 998 )
replace IRSSP3 = . if (IRSSP3 >= 999 )
replace IRSSP4 = . if (IRSSP4 >= 998 )
replace IRSSP5 = . if (IRSSP5 >= 181 )
replace IRCPE1 = . if (IRCPE1 >= 998 )
replace IRCPE2 = . if (IRCPE2 >= 998 )
replace IRCPE3 = . if (IRCPE3 >= 999 )
replace IRCPE4 = . if (IRCPE4 >= 999 )
replace IRCPE5 = . if (IRCPE5 >= 998 )
replace IREMG1 = . if (IREMG1 >= 998 )
replace IREMG2 = . if (IREMG2 >= 998 )
replace IREMG3 = . if (IREMG3 >= 998 )
replace IREMG4 = . if (IREMG4 >= 998 )
replace IREMG5 = . if (IREMG5 >= 998 )
replace IRCDCIG = . if (IRCDCIG >= 81 )
replace IRCDALC = . if (IRCDALC >= 81 )
replace IRCDMJ = . if (IRCDMJ >= 81 )
replace IRCDCOC = . if (IRCDCOC >= 81 )
replace IREFCIG = . if (IREFCIG >= 81 )
replace IREFALC = . if (IREFALC >= 81 )
replace IREFMJ = . if (IREFMJ >= 81 )
replace IREFCOC = . if (IREFCOC >= 81 )
replace IRUDCIG = . if (IRUDCIG >= 81 )
replace IRUDALC = . if (IRUDALC >= 81 )
replace IRUDMJ = . if (IRUDMJ >= 81 )
replace IRUDCOC = . if (IRUDCOC >= 81 )
replace IRDPCIG = . if (IRDPCIG >= 81 )
replace IRDPALC = . if (IRDPALC >= 81 )
replace IRDPMJ = . if (IRDPMJ >= 81 )
replace IRDPCOC = . if (IRDPCOC >= 81 )
replace IRWSCIG = . if (IRWSCIG >= 81 )
replace IRWSALC = . if (IRWSALC >= 81 )
replace IRWSMJ = . if (IRWSMJ >= 81 )
replace IRWSCOC = . if (IRWSCOC >= 81 )
replace INTMONTH = . if (INTMONTH >= 81 )
replace QC06 = . if (QC06 >= 81 )
replace QC09 = . if (QC09 >= 81 )
replace AL02 = . if (AL02 >= 81 )
replace SE04 = . if (SE04 >= 81 )
replace TR04 = . if (TR04 >= 81 )
replace ST04 = . if (ST04 >= 81 )
replace ST07 = . if (ST07 >= 81 )
replace AN04 = . if (AN04 >= 81 )
replace MJ04 = . if (MJ04 >= 81 )
replace IN04 = . if (IN04 >= 81 )
replace CC04 = . if (CC04 >= 81 )
replace CC10 = . if (CC10 >= 81 )
replace CC11 = . if (CC11 >= 81 )
replace LS05 = . if (LS05 >= 81 )
replace LS08 = . if (LS08 >= 81 )
replace HE04 = . if (HE04 >= 81 )
replace HE07 = . if (HE07 >= 81 )
replace DR08 = . if (DR08 >= 81 )
replace SP04 = . if (SP04 >= 81 )
replace SP08 = . if (SP08 >= 81 )
replace OTHDOSP1 = . if (OTHDOSP1 >= 81 )
replace OTHDOSP2 = . if (OTHDOSP2 >= 81 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

